package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@(!`0D```````````(`/@`!````H"1```````!``````````/#&````
M`````````$``.``(`$``'0`<``8````%````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````=`````````!T``````````0`````````!````
M!0````````````````!``````````$```````!3!````````%,$`````````
M`"````````$````&````&,$````````8P6```````!C!8```````R`0`````
M``!("0``````````(````````@````8```!`P0```````$#!8```````0,%@
M``````#P`0```````/`!````````"``````````$````!````"`"````````
M(`)````````@`D```````$0`````````1``````````$`````````%#E=&0$
M````S+P```````#,O$```````,R\0```````W`````````#<``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````"``````````O;&EB+VQD+6MF<F5E8G-D+7@X-BTV-"YS;RXQ
M``````0````0`````0```$=.50`#````!@``````````````!````!0````#
M````1TY5`,MX4L"HW2826PW,]>BY(P9=E7\)`````&$```!P````"@``````
M````````/0````````!&````10`````````S````)@```#L````V````#P``
M`#<```!@`````````"X```!2````4P```$P```!F````3@```#H````C````
M```````````2````20```"L``````````````%0```!?````)0````D```!-
M````;P```%<````6````2P`````````'`````````%X`````````40```#X`
M`````````````&H````G`````````!L``````````````%`````Q````"P``
M`$,``````````````$0`````````/```````````````'@`````````$````
M/P```$(```!`````8P```&T``````````````&<```!9````.````!@```!*
M`````0```#``````````#````````````````````&L```!8`````````$$`
M``!:````+0```#D````T````$```````````````````````````````````
M`````````````````````````````````&@`````````````````````````
M````````````````````````````````#@```&(`````````%```````````
M```````````````#``````````````!I``````````````!;````90``````
M```````````````````1````'````````````````````"$````(````*@``
M``````!A````(@````T`````````3P```"\``````````````!D````H````
M50```!H````&```````````````?````$P```"D`````````5@```$<```!=
M````2`````4````@````````````````````7```````````````````````
M```D`````````#4````````````````````7`````@```&X````L````,@``
M```````=`````````!4``````````````````````````````&P`````````
M````````````````9```````````````$0```$P````$````"````"`0$``%
M0`2&J@(``8"&`:A"*``@3R`$"[BB.$VZA`8*3````$X```!3````6````%D`
M``!@````8@```&0```!G````:@````````!L````;@````````!O````````
M``````!Z\$IKH2(+(.K3[PYNQ=\?1I@%QL[>1RUK?YI\+L6;MM1DU'Q\08[%
M(/_D#KF-\0[9<5@<XD?&`;(!BV^L2^/`PN4_++KCDGSRV],=^Z%L8&H)0]:'
M^9R!Q+F<0&>OS&8X\HL<Q(D%D$-%U>P,%.*>R-6R<>?O7WLR8MOMV\WCG@PZ
MEPNGW:-K?ZF<FZ/@^TD`````````````````````````````````````_`,`
M`!(`````````````````````````L0```!(`````````````````````````
MD@$``!(`````````````````````````EP$``!(`````````````````````
M````:P(``!(`````````````````````````\@,``!(`````````````````
M````````!`0``!(`````````````````````````$0```"``````````````
M````````````(````"``````````````````````````?@$``!(`````````
M````````````````<@,``!(`````````````````````````7P$``!(`````
M````````````````````<0$``!(`````````````````````````$P,``!(`
M````````````````````````)0,``!(`````````````````````````]@(`
M`!(`````````````````````````'0(``!(`````````````````````````
M90,``!(`````````````````````````_0```!(`````````````````````
M````#0(``!(`````````````````````````B`,``!(`````````````````
M````````*@,``!(`````````````````````````NP$``!(`````````````
M````````````Q`0``!(`````````````````````````B0(``!(`````````
M````````````````VP$``!(`````````````````````````)@(``!(`````
M````````````````````+P$``!(`````````````````````````-````!(`
M````````````````````````QP,``!(`````````````````````````@@(`
M`!(`````````````````````````Z@,``!(`````````````````````````
M3@$``!(`````````````````````````R````!(`````````````````````
M````Z`(``!(`````````````````````````@0,``!(`````````````````
M````````CP,``!(`````````````````````````U`(``!(`````````````
M````````````XP,``!(`````````````````````````,@,``!(`````````
M````````````````30(``!(`````````````````````````W`,``!(`````
M````````````````````J@,``!(`````````````````````````SP(``!(`
M````````````````````````R`(``!(`````````````````````````/P(`
M`!(`````````````````````````M0,``!(`````````````````````````
MG`$``!(`````````````````````````5`,``!(`````````````````````
M````"P0``!(`````````````````````````.@,``!(`````````````````
M````````HP,``!(`````````````````````````[````!(`````````````
M````````````0@```!(`````````````````````````>@,``!(`````````
M````````````````UP```!(`````````````````````````[P$``!(`````
M````````````````````;`,``!(`````````````````````````=@(``!(`
M````````````````````````00$``!(`````````````````````````'0$`
M`!(`````````````````````````0P,``!(`````````````````````````
M\`(``!(`````````````````````````E@,``!(`````````````````````
M````-`(``!(`````````````````````````O0,``!(`````````````````
M````````5````!(`````````````````````````3`,``!(`````````````
M````````````R0$``!(`````````````````````````8P```!(`````````
M````````````````CP```!(`````````````````````````G0,``!(`````
M````````````````````$@0``!(`````````````````````````>````!(`
M````````````````````````"P$``!(`````````````````````````6P(`
M`!(```#((4``````````````````/04``!$`&0#8Q6````````@`````````
M?`0``!(`#P!H74``````````````````S00``!(`#@"P2$```````'\`````
M````#04``!$`&0#0Q6````````@`````````404``!(`#@!034```````+@*
M````````'P0``!(`#@`P24```````"L"````````5`0``!(`#@"0)4``````
M``,`````````@@0``!(`#@`06$```````-0#````````(04``!(`#@``/D``
M`````$``````````<`4``!(`#@!@2T```````.L!````````]P0``!(`#`"P
M'T``````````````````0P0``!``\?_@Q6``````````````````900``!(`
M#@"@)4```````#0`````````F`0``!(`#@!@/4```````$P`````````V00`
M`!$`$`"`74````````0`````````]00``!(`#@#P6T```````"T`````````
M3P0``!``\?]@RF``````````````````E`(``!$`&@#PQ6```````!,`````
M````7@4``!(`#@!P1$```````"0!````````Z`0``!``&0"XQ6``````````
M````````H````!(```#8(4``````````````````)`0``!$`&@#@Q6``````
M``@`````````I@0``!(`#@"@1T````````(!````````U0,``!$`&@#HQ6``
M``````@`````````)00``"$`&@#@Q6````````@`````````/`0``!``\?_@
MQ6``````````````````<@0``!(`#@"07$````````(`````````J`$``!(`
M``!(($``````````````````$@4``!$`$`#@8$```````.I;````````[@0`
M`!(`#@"@)$``````````````````_00``!(`#@"@7$```````(D`````````
MZ@0``"``&0"XQ6``````````````````)@0``"$`&@#@Q6````````@`````
M````L@0``!(`#@!P1T```````"(`````````?04``!(`#@"@14```````,L!
M`````````&QI8G!E<FPN<V\N-2XQ,`!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G
M:7-T97)#;&%S<V5S`%!E<FQ?<WES7W1E<FT`4&5R;%])<W1A=&)U9E]P='(`
M4&5R;%]S>7-?:6YI=#,`4&5R;%])97AI=%]F;&%G<U]P='(`4&5R;%]S879E
M7V1E<W1R=6-T;W)?>`!097)L7TEC;VUP8W9?<'1R`%!E<FQ?871F;W)K7VQO
M8VL`4&5R;%])8W5R<W1A8VMI;F9O7W!T<@!P97)L7V-O;G-T<G5C=`!097)L
M7V-R;V%K7VYO8V]N=&5X=`!097)L7TEP87)S97)?<'1R`%!E<FQ?879?<VAI
M9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%])=&]P7V5N=E]P='(`4&5R;%])
M=&%I;G1E9%]P='(`4&5R;%]N97=35G!V`%!E<FQ?;F5W6%-?9FQA9W,`4&5R
M;%]):6Y?979A;%]P='(`4&5R;%]);W!?<'1R`%!E<FQ?265V86Q?<F]O=%]P
M='(`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!0
M97)L7W-V7W-E='!V`%!E<FQ?1W1H<E]K97E?<'1R`%!E<FQ?1V1O7W5N9'5M
M<%]P='(`4&5R;%])<&5R;%]D97-T<G5C=%]L979E;%]P='(`4&5R;%]G=E]F
M971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=84P!P97)L
M7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?
M<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?;65M;W)Y
M7W=R87``;&EB9&PN<V\N,@!L:6)M+G-O+C$`;&EB<'1H<F5A9"YS;RXP`&]P
M96XV-`!R96%D`'!T:')E861?9V5T<W!E8VEF:6,`;'-E96LV-`!C;&]S90!?
M7V5R<FYO7VQO8V%T:6]N`&QI8F,N<V\N,"XQ`%]?<F5G:7-T97)?871F;W)K
M`&5X:70`<W!R:6YT9@!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`'-T<FYC
M<'D`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!G971P
M:60`<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R`')M9&ER`&UE;6-P>0!?
M7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`%]?8W1Y<&5?8E]L;V,`<W1D
M97)R`&=E='5I9`!E>&5C=G``9G!R:6YT9@!R96%D9&ER-C0`;65M;6]V90!A
M8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!L:6)C
M<GEP="YS;RXQ`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`'!A<E]C=7)R96YT
M7V5X96,`<&%R7V)A<V5N86UE`%]?;&EB8U]C<W5?9FEN:0!84U]);G1E<FYA
M;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?9&ER;F%M90!G971?=7-E
M<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E
M9`!?7V1A=&%?<W1A<G0`>'-?:6YI=`!?7VQI8F-?8W-U7VEN:70`;F%M95]L
M;V%D7VUY7W!A<E]P;`!84U]);G1E<FYA;'-?4$%27T-,14%24U1!0TL`<VEZ
M95]L;V%D7VUY7W!A<E]P;`!P87)?;6MT;7!D:7(`<&%R7W-E='5P7VQI8G!A
M=&@`<&%R7V9I;F1P<F]G`'!A<E]I;FET7V5N=@!'3$E"0U\R+C,`1TQ)0D-?
M,BXT`$=,24)#7S(N,RXR`````@```````@````(``@`````````"```````#
M``(`!`````(```````(``@````(```````````````(``@`"```````$``(`
M`@`$``(``@````(``@`$``0````"````!0`"``(``@```````@```````@``
M```````"``0``@````(````"``````````(``@`````````!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$````!``$````"``$``@`"``$``0``
M``$``0`!``$``@`!``$``````````0`!`+@"```0````(````!-I:0T```0`
MB@4````````!``,`!P,``!``````````%&EI#0``!0"4!0``$````'(9:0D`
M``,`G@4``!`````3:6D-```"`(H%````````,,-@```````&````"```````
M````````X,5@```````%````8@``````````````Z,5@```````%````9```
M````````````\,5@```````%````7@``````````````6,-@```````'````
M`0``````````````8,-@```````'`````@``````````````:,-@```````'
M`````P``````````````<,-@```````'````!```````````````>,-@````
M```'````!0``````````````@,-@```````'````!@``````````````B,-@
M```````'````!P``````````````D,-@```````'````:```````````````
MF,-@```````'````"@``````````````H,-@```````'````"P``````````
M````J,-@```````'````#```````````````L,-@```````'````#0``````
M````````N,-@```````'````#@``````````````P,-@```````'````#P``
M````````````R,-@```````'````$```````````````T,-@```````'````
M$0``````````````V,-@```````'````$@``````````````X,-@```````'
M````$P``````````````Z,-@```````'````%```````````````\,-@````
M```'````%0``````````````^,-@```````'````%@```````````````,1@
M```````'````%P``````````````",1@```````'````&```````````````
M$,1@```````'````&0``````````````&,1@```````'````&@``````````
M````(,1@```````'````&P``````````````*,1@```````'````'```````
M````````,,1@```````'````'0``````````````.,1@```````'````'@``
M````````````0,1@```````'````'P``````````````2,1@```````'````
M(```````````````4,1@```````'````3```````````````6,1@```````'
M````80``````````````8,1@```````'````(0``````````````:,1@````
M```'````(@``````````````<,1@```````'````(P``````````````>,1@
M```````'````)```````````````@,1@```````'````)0``````````````
MB,1@```````'````)@``````````````D,1@```````'````)P``````````
M````F,1@```````'````*```````````````H,1@```````'````*0``````
M````````J,1@```````'````*@``````````````L,1@```````'````*P``
M````````````N,1@```````'````+```````````````P,1@```````'````
M+0``````````````R,1@```````'````+@``````````````T,1@```````'
M````+P``````````````V,1@```````'````,```````````````X,1@````
M```'````,0``````````````Z,1@```````'````,@``````````````\,1@
M```````'````,P``````````````^,1@```````'````-```````````````
M`,5@```````'````-0``````````````",5@```````'````-@``````````
M````$,5@```````'````-P``````````````&,5@```````'````.```````
M````````(,5@```````'````.0``````````````*,5@```````'````.@``
M````````````,,5@```````'````.P``````````````.,5@```````'````
M/```````````````0,5@```````'````/0``````````````2,5@```````'
M````/@``````````````4,5@```````'````/P``````````````6,5@````
M```'````0```````````````8,5@```````'````00``````````````:,5@
M```````'````0@``````````````<,5@```````'````0P``````````````
M>,5@```````'````1```````````````@,5@```````'````10``````````
M````B,5@```````'````1@``````````````D,5@```````'````1P``````
M````````F,5@```````'````2```````````````H,5@```````'````20``
M````````````J,5@```````'````2@``````````````L,5@```````'````
M2P``````````````2(/L".@7!0``Z*(%``#H;3T``$B#Q`C#_S5ZHR``_R5\
MHR``#Q]``/\E>J,@`&@`````Z>#_____)7*C(`!H`0```.G0_____R5JHR``
M:`(```#IP/____\E8J,@`&@#````Z;#_____)5JC(`!H!````.F@_____R52
MHR``:`4```#ID/____\E2J,@`&@&````Z8#_____)4*C(`!H!P```.EP____
M_R4ZHR``:`@```#I8/____\E,J,@`&@)````Z5#_____)2JC(`!H"@```.E`
M_____R4BHR``:`L```#I,/____\E&J,@`&@,````Z2#_____)1*C(`!H#0``
M`.D0_____R4*HR``:`X```#I`/____\E`J,@`&@/````Z?#^____)?JB(`!H
M$````.G@_O___R7RHB``:!$```#IT/[___\EZJ(@`&@2````Z<#^____)>*B
M(`!H$P```.FP_O___R7:HB``:!0```#IH/[___\ETJ(@`&@5````Z9#^____
M)<JB(`!H%@```.F`_O___R7"HB``:!<```#I</[___\ENJ(@`&@8````Z6#^
M____);*B(`!H&0```.E0_O___R6JHB``:!H```#I0/[___\EHJ(@`&@;````
MZ3#^____)9JB(`!H'````.D@_O___R62HB``:!T```#I$/[___\EBJ(@`&@>
M````Z0#^____)8*B(`!H'P```.GP_?___R5ZHB``:"````#IX/W___\E<J(@
M`&@A````Z=#]____)6JB(`!H(@```.G`_?___R5BHB``:",```#IL/W___\E
M6J(@`&@D````Z:#]____)5*B(`!H)0```.F0_?___R5*HB``:"8```#I@/W_
M__\E0J(@`&@G````Z7#]____)3JB(`!H*````.E@_?___R4RHB``:"D```#I
M4/W___\E*J(@`&@J````Z4#]____)2*B(`!H*P```.DP_?___R4:HB``:"P`
M``#I(/W___\E$J(@`&@M````Z1#]____)0JB(`!H+@```.D`_?___R4"HB``
M:"\```#I\/S___\E^J$@`&@P````Z>#\____)?*A(`!H,0```.G0_/___R7J
MH2``:#(```#IP/S___\EXJ$@`&@S````Z;#\____)=JA(`!H-````.F@_/__
M_R72H2``:#4```#ID/S___\ERJ$@`&@V````Z8#\____)<*A(`!H-P```.EP
M_/___R6ZH2``:#@```#I8/S___\ELJ$@`&@Y````Z5#\____):JA(`!H.@``
M`.E`_/___R6BH2``:#L```#I,/S___\EFJ$@`&@\````Z2#\____)9*A(`!H
M/0```.D0_/___R6*H2``:#X```#I`/S___\E@J$@`&@_````Z?#[____)7JA
M(`!H0````.G@^____R5RH2``:$$```#IT/O___\E:J$@`&A"````Z<#[____
M)6*A(`!H0P```.FP^____R5:H2``:$0```#IH/O___\E4J$@`&A%````Z9#[
M____)4JA(`!H1@```.F`^____R5"H2``:$<```#I</O___\E.J$@`&A(````
MZ6#[____)3*A(`!H20```.E0^____R4JH2``:$H```#I0/O___\E(J$@`&A+
M````Z3#[__\``````````#'M28GQ2(LW2(U7"$B#Y/!05$G'P)!<0`!(Q\&@
M7$``2,?',$E``.B<____])"0D$B#[`A(BP55GB``2(7`=`+_T$B#Q`C#D)"0
MD)"0D)"054B)Y5-(@^P(@#T(H2```'5+NS#!8`!(BP4"H2``2('K*,%@`$C!
M^P-(@^L!2#G8<R1F#Q]$``!(@\`!2(D%W:`@`/\4Q2C!8`!(BP7/H"``2#G8
M<N+&!;N@(``!2(/$"%O)PV9F9BX/'X0``````%5(@SW/FR```$B)Y702N```
M``!(A<!T"+\XP6``R?_@R<.0D)"0D)"0D)"0D)"0D#'`PV9F9F8N#Q^$````
M```/M@](B?B$R70H2(L%SSD``$B-5P$/MC!(B?@/'T0``$`X\0^V"D@/1,)(
M@\(!A,EU[O/#9F9F+@\?A```````54R-3S@QR5-(@>P0`@``2(UT)(@/'T``
M28L4"4B)T$F)T$C!X`A)P>`808/@_R4``/\`3`G`28G02<'H"$&!X`#_``!,
M"<!)B=!)P>@808'@_P```$P)P$F)T$G!Z"!(B01.3(G`2<'@&$C!X`A!@^#_
M)0``_P!,"<!)B=!(P>HX2<'H*$&!X`#_``!,"<!("=!(B41."$B#P0A(@_E`
M#X5S____2(U6:$B!QF@"``!(BT+82#,"2#-"J$@S0IA(B<%(`<!(P>D?2`G!
M@^'_2(E*&$B#P@A(.?)UU$R+!TB+3R!(`TPDB$B+5PA(BU\02(MW&$R)P$R)
MQ4C!Y05(P>@;2`GH@^#_3(V4`9EY@EI(B=!(B=E(]]!((=%((?!(`W0DD$@)
MR$R)P4$!PDB)T$C!XAY(P>@"2/?12`G02"'92`-<))B#X/](B<),(<)("<I,
MB=%,C8P6F7F"6DR)TDC!X05(P>H;3(G62`G*3(G!1HT,"DR)PDC!Z0)(P>(>
M2`G13(G23(G-@^'_2/?22"'.2"'"2`GR2(VT$YEY@EI,B<I,B<M(P>,%2,'J
M&T@)VDR)RXTT,DR)TDG!XAY(P>H"2/?33`G22`-$)*!((<N#XO](`TPDJ$@A
MU4@)ZTB)]4R-E!B9>8):2(GP2(GS2,'C!4C!Z!M("=A(B?-&C1003(G(2<'A
M'DC!Z`)(]]-,"<A((=-(`U0DL(/@_T@AQ4@)ZTR-C!F9>8):3(G13(G32,'C
M!4C!Z1M("=E,B=-&C0P)2(GQ2,'F'DC!Z0)(]]-("?%,B=9((<.#X?],B<U(
M(<Y("?-(C;0:F7F"6DR)RDR)RTC!XP5(P>H;2`G:3(G+C30R3(G22<'B'DC!
MZ@)(]]-,"=)(`T0DN$@ARX/B_T@#3"3`2"'52`GK2(GU3(V4&)EY@EI(B?!(
MB?-(P>,%2,'H&T@)V$B)\T:-%!!,B<A)P>$>2,'H`DCWTTP)R$@ATT@#5"3(
M@^#_2"'%2`GK3(V,&9EY@EI,B=%,B=-(P>,%2,'I&T@)V4R)TT:-#`E(B?%(
MP>8>2,'I`DCWTT@)\4R)UD@APX/A_TR)S4@ASD@)\TB-M!J9>8):3(G*3(G+
M2,'C!4C!ZAM("=I,B<N--#),B=))P>(>2,'J`DCWTTP)TD@#1"302"'+@^+_
M2`-,)-A((=5(">M(B?5,C908F7F"6DB)\$B)\TC!XP5(P>@;2`G82(GS1HT4
M$$R)R$G!X1Y(P>@"2/?33`G(2"'32`-4)."#X/]((<5(">M,C8P9F7F"6DR)
MT4R)TTC!XP5(P>D;2`G93(G31HT,"4B)\4C!YAY(P>D"2/?32`GQ3(G62"'#
M@^'_3(G-2"'.2`GS2(VT&IEY@EI,B<I,B<M(P>,%2,'J&T@)VDR)RXTT,DR)
MTDG!XAY(P>H"2/?33`G22`-$).A((<N#XO](`TPD\$@AU4@)ZTB)]4R-E!B9
M>8):2(GP2(GS2,'C!4C!Z!M("=A(B?-&C1003(G(2<'A'DC!Z`)(]]-,"<A(
M(=-(`U0D^(/@_T@AQ4@)ZTR-C!F9>8):3(G13(G32,'C!4C!Z1M("=E,B=-&
MC0P)2(GQ2,'F'DC!Z0)(]]-("?%,B=9((<.#X?],B<U((<Y("?-(C;0:F7F"
M6DR)RDR)RTC!XP5(P>H;2`G:3(G+C30R3(G22<'B'DC!Z@)(]]-,"=)(`P0D
M2"'+@^+_2`-,)`A((=5(">M(B?5,C908F7F"6DB)\$B)\TC!XP5(P>@;2`G8
M2(GS1HT4$$R)R$G!X1Y(P>@"2/?33`G(2"'32`-4)!"#X/]((<5(">M,C8P9
MF7F"6DR)T4R)TTC!XP5(P>D;2`G93(G31HT,"4B)\4C!YAY(P>D"2/?32`GQ
M3(G62"'#@^'_3(G-2"'.2`GS2(VT&IEY@EI,B<I,B<M(P>,%2,'J&T@)VDR)
MRXTT,DR)TDG!XAY(P>H"2/?33`G22`-$)!A((<N#XO](`TPD($@AU4@)ZTB-
MK!B9>8):2(GP2(GS2,'C!4C!Z!M("=B)ZXTL&$R)R$G!X1Y(P>@"2(GS3`G(
M2/?328GQ@^#_2"'32`-4)"A)(<%,"<M,C8P9F7F"6DB)Z4B)ZTC!XP5(P>D;
M2`G91HT,"4B)\4C!YAY(P>D"2`GQ3(G.@^'_2,'F!4B)RT@QPT@QZTB-G!JA
MZ]EN3(G*2,'J&T@)\HT<&DB)ZDC!Y1Y(P>H"2`GJ@^+_2`-$)#!(B=9(,<Y(
M`TPD.$PQSDB-K#"AZ]EN2(G82(G>2,'F!4C!Z!M("?")[HTL,$R)R$G!X1Y(
MP>@"3`G(28GI@^#_2<'A!4B)QD@QUD@#5"1`2#'>2(VT,:'KV6Y(B>E(P>D;
M3`G)C30Q2(G92,'C'DC!Z0)("=E)B?&#X?])P>$%2(G+2#'#2`-$)$A(,>M(
MC9P:H>O9;DB)\DC!ZAM,"<J-'!I(B>I(P>4>2,'J`D@)ZDF)V8/B_TB)U4@Q
MS4@Q]4G!X05(`TPD4$B-K"BAZ]EN2(G82,'H&TP)R$&)Z4*-+`A(B?!(P>8>
M2,'H`D@)\$F)Z8/@_TG!X05(B<9(,=9(`U0D6$@QWDB-M#&AZ]EN2(GI2,'I
M&TP)R8TT,4B)V4C!XQY(P>D"2`G928GQ@^'_2<'A!4B)RT@QPT@#1"1@2#'K
M2(V<&J'KV6Y(B?)(P>H;3`G*C1P:2(GJ2,'E'DC!Z@)(">I)B=F#XO])P>$%
M2(G52#'-2#'U2(VL**'KV6Y(B=A(P>@;3`G(08GJ2`-,)&A"C2P02(GP2,'F
M'DC!Z`)("?!)B>F#X/])P>$%2(G&2#'62`-4)'!(,=Y(C;0QH>O9;DB)Z4C!
MZ1M,"<F--#%(B=E(P>,>2,'I`D@)V4F)\8/A_TG!X05(B<M(,<-(`T0D>$@Q
MZTB-G!JAZ]EN2(GR2,'J&TP)RHT<&DB)ZDC!Y1Y(P>H"2`GJ28G9@^+_2<'A
M!4B)U4@QS4@Q]4B-K"BAZ]EN2(G82,'H&TP)R$&)Z4*-+`A(B?!(P>8>2,'H
M`D@)\$@#C"2`````28GI@^#_2<'A!4B)QD@QUD@#E"2(````2#'>2(VT,:'K
MV6Y(B>E(P>D;3`G)C30Q2(G92,'C'DC!Z0)("=E)B?&#X?])P>$%2(G+2#'#
M2`.$))````!(,>M(C9P:H>O9;DB)\DC!ZAM,"<J-'!I(B>I(P>4>2,'J`D@)
MZDF)V8/B_TG!X05(B=5(,<U(`XPDF````$@Q]4B-K"BAZ]EN2(G82,'H&TP)
MR$&)ZD*-+!!(B?!(P>8>2,'H`D@)\$F)Z8/@_TB)QD@QUDG!X05(`Y0DH```
M`$@QWDB-M#&AZ]EN2(GI2,'I&TP)R8TT,4B)V4C!XQY(P>D"2`G928GQ@^'_
M2<'A!4B)RT@QPT@#A"2H````2#'K2(V<&J'KV6Y(B?)(P>H;3`G*C1P:2(GJ
M2,'E'DC!Z@)(">J#XO](B=5(,<U(`XPDL````$@Q]4R-C"BAZ]EN2(G82(G=
M2,'E!4C!Z!M(">A&C0P(2(GP2,'F'DC!Z`)("?"#X/](B<9(,=9(,=Y(C:PQ
MH>O9;DR)R4R)SDC!Z1M(P>8%2`.4)+@```!("?&)[HTL,4B)WDC!XQY(P>X"
M2`G>@^;_2(GQ2#'!2`.$),````!,,<E(C9P*H>O9;DB)ZDB)Z4C!X05(P>H;
M2`G*3(G)2<'A'DC!Z0*-'!I,"<F#X?](B<I(,?)(,>I,C8P0H>O9;DB)V$B)
MVDC!X@5(P>@;2`G02(GJ2,'E'D:-#`A(P>H"N-R\&X](">I(B<5(`ZPDR```
M`(/B_TF)TDDARDB-=#4`2(G52`G-2"'=3`G538G*2(TL+DR)SDG!X@5(P>X;
M3`G608GJ0HTL%DB)WDC!XQY(P>X"2`G>2(G#2`.<)-````"#YO])B?))(=)(
MC0P+2(GS2`G33"'+3`G328GJ2(T<&4B)Z4G!X@5(P>D;3`G1C1P93(G)2<'A
M'DC!Z0),"<E)B<%,`XPDV````(/A_TF)RDDA\DF-%!%)B<E)"?%)(>E-"=%)
MB=I.C0P*2(G:2<'B!4C!ZAM,"=)&C0P*2(GJ2,'E'DC!Z@)(">I(B<5(`ZPD
MX````(/B_TF)TDDARDB-=#4`2(G52`G-2"'=3`G538G*2(TL+DR)SDG!X@5(
MP>X;3`G608GJ0HTL%DB)WDC!XQY(P>X"2`G>2(G#2`.<).@```"#YO])B?))
M(=)(C0P+2(GS2`G33"'+3`G328GJ2(T<&4B)Z4G!X@5(P>D;3`G1C1P93(G)
M2<'A'DC!Z0),"<E)B<%,`XPD\````(/A_TF)RDDA\DF-%!%)B<E)"?%)(>E-
M"=%)B=I.C0P*2(G:2<'B!4C!ZAM,"=)&C0P*2(GJ2,'E'DC!Z@)(">I(B<5(
M`ZPD^````(/B_TF)TDB-=#4`2(G52`G-22'*2"'=3`G538G*2(TL+DR)SDG!
MX@5(P>X;3`G608GJ0HTL%DB)WDC!XQY(P>X"2`G>2(G#2`.<)``!``"#YO])
MB?))(=)(C0P+2(GS2`G33"'+3`G328GJ2(T<&4B)Z4G!X@5(P>D;3`G1C1P9
M3(G)2<'A'DC!Z0),"<E)B<%,`XPD"`$``(/A_TF)RDDA\DF-%!%)B<E)"?%)
M(>E-"=%)B=I.C0P*2(G:2<'B!4C!ZAM,"=)&C0P*2(GJ2,'E'DC!Z@)(">I(
MB<5(`ZPD$`$``(/B_TF)TDDARDB-=#4`2(G52`G-2"'=3`G538G*2(TL+DR)
MSDG!X@5(P>X;3`G608GJ0HTL%DB)WDC!XQY(P>X"2`G>2(G#2`.<)!@!``"#
MYO])B?))(=)(C0P+2(GS2`G33"'+3`G328GJ2(T<&4B)Z4G!X@5(P>D;3`G1
MC1P93(G)2<'A'DC!Z0),"<E)B<%,`XPD(`$``(/A_TF)RDDA\DF-%!%)B<E)
M"?%)(>E-"=%)B=I.C0P*2(G:2<'B!4C!ZAM,"=)&C0P*2(GJ2,'E'DC!Z@)(
M">I(B<5(`ZPD*`$``(/B_TF)TDDARDB-=#4`2(G52`G-2"'=3`G538G*2(TL
M+DR)SDG!X@5(P>X;3`G608GJ0HTL%DB)WDC!XQY(P>X"2`G>2(G#2`.<)#`!
M``"#YO])B?))(=)(C0P+2(GS2`G33"'+3`G328GJ2(T<&4B)Z4G!X@5(P>D;
M3`G1C1P93(G)2<'A'DC!Z0),"<E)B<%,`XPD.`$``(/A_TF)RDDA\DF-%!%)
MB<E)"?%)(>E-"=%)B=I.C0P*2(G:2<'B!4C!ZAM,"=)&C0P*2(GJ2,'E'DC!
MZ@)(">I(B<5(`ZPD0`$``(/B_TF)TDDARDB-=#4`2(G52`G-2"'=3`G538G*
M2(TL+DR)SDG!X@5(P>X;3`G608GJ0HTL%DB)WDC!XQY(P>X"2`G>2(G#2`.<
M)$@!``"#YO])B?))(=)(C0P+2(GS2`G33"'+3`G328GJ2(T<&4B)Z4G!X@5(
MP>D;3`G1C1P93(G)2<'A'DC!Z0),"<E)B<%,`XPD4`$``(/A_TF)RDF-%!%)
MB<E)"?%)(?))(>E-"=%)B=I.C0P*2(G:2<'B!4C!ZAM,"=)&C0P*2(GJ2,'E
M'DC!Z@)(">I(B<5(`ZPD6`$``(/B_T@#A"1@`0``28G222'*2(UT-0!(B=5(
M"<U(C0P(2"'=3`G538G*2(TL+DR)SDG!X@5(P>X;3`G608GJ0HTL%DB)WDC!
MXQY(P>X"38G*2`G>2<'J`H/F_TB)\$B)\T@)T$@ATTPAR$G!X1Y("=A(C1P!
M2(GH2(GI2,'A!4C!Z!M("<A-"<J-'!BXUL%BRD&#XO](B<%(`XPD:`$``$F)
MV4G!X05(C1013(G12#'Q2#'I2(T,"DB)VDC!ZAM,"<I)B>E(P>4>1(T<"DB)
MPD@#E"1P`0``2<'I`DD)Z4R)V4&#X?](P>$%2(TT,DR)RDPQTD@QVDB-+!9,
MB=I(P>H;2`G*B>F-+`I(B=E(P>,>2,'I`D@)V4B)PT@#G"1X`0``@^'_2(GN
M2(G*2,'F!4PQRDPQVDP!TT@!TTB)ZDC!ZAM("?)(B<:-'!I,B=I)P>,>2,'J
M`DP)VH/B_T@#M"2``0``3HT,#DB)UD@QSD@Q[DV-'#%(B=Y)B=E)P>$%2,'N
M&TP)SD:-'!Y(B>Y(P>4>2,'N`D@)[DB)Q4@#K"2(`0``@^;_38G92<'A!4B-
M3`T`2(GU2#'52#'=2(TL*4R)V4C!Z1M,"<E!B>E&C10)2(G92,'C'DC!Z0)(
M"=E(B<-(`YPDD`$``(/A_TR)U4C!Y05(C1032(G+2#'S3#';2(T<&DR)TDC!
MZAM(">I$C0P:3(G:2(G#2`.<))@!``!)P>,>2,'J`DP)VH/B_TB--#-(B=-(
M,<M,,=-,C1P>3(G+3(G.2,'F!4C!ZQM("?-,B=9)P>(>1HT<&TB)PT@#G"2@
M`0``2,'N`DP)UDR)W8/F_TC!Y05(C0P+2(GS2#'33#'+2(T<&4R)V4C!Z1M(
M">E$C1093(G)2(G#2`.<)*@!``!)P>$>2,'I`DP)R4R)U8/A_TC!Y05(C103
M2(G+2#'S3#';2(T<&DR)TDC!ZAM(">I$C0P:3(G:2(G#2`.<)+`!``!)P>,>
M2,'J`DP)VH/B_TB--#-(B=-(,<M,,=-,C1P>3(G+3(G.2,'F!4C!ZQM("?-,
MB=9)P>(>1HT<&TB)PT@#G"2X`0``2,'N`DP)UDR)W8/F_TC!Y05(C0P+2(GS
M2#'33#'+2(T<&4R)V4C!Z1M(">E$C1093(G)2(G#2`.<),`!``!)P>$>2,'I
M`DP)R4R)U8/A_TC!Y05(C1032(G+2#'S3#';2(T<&DR)TDC!ZAM(">I$C0P:
M3(G:2(G#2`.<),@!``!)P>,>2,'J`DP)VH/B_TB--#-(B=-(,<M,,=-,C1P>
M3(G+3(G.2,'F!4C!ZQM("?-,B=9)P>(>2,'N`D:-'!M(B<-,"=9(`YPDT`$`
M`(/F_TR)W4C!Y05(C0P+2(GS2#'33#'+2(T<&4R)V4C!Z1M(">E$C1093(G)
M2(G#2`.<)-@!``!)P>$>2,'I`DP)R4R)U8/A_TC!Y05(C1032(G+2#'S3#';
M2(T<&DR)TDC!ZAM(">I$C0P:3(G:2(G#2`.<).`!``!)P>,>2,'J`DP)VH/B
M_TB--#-(B=-(,<M,,=-,C1P>3(G+3(G.2,'F!4C!ZQM("?-,B=9)P>(>1HT<
M&TB)PT@#G"3H`0``2,'N`DP)UDR)W8/F_TB-#`M(B?-(,=-(P>4%3#'+2(T<
M&4R)V4C!Z1M(">E$C1093(G)2(G#2`.<)/`!``!)P>$>2,'I`DP)R4R)U8/A
M_TC!Y05(C1032(G+2#'S3#';2(T<&DR)TDC!ZAM(">I$C0P:3(G:2(G#2`.<
M)/@!``!(P>H"2<'C'DP)VD@#A"0``@``@^+_2(TT,TB)TT@QRTB-#`A,,=-(
MC2P>3(G+3(G.2,'F!4C!ZQM("?.)[HTL,TR)UDG!XAY(P>X"3(G+3`G638G*
M2,'K`H/F_TG!XAY(B?!,"=-(,=!,,<A)B>E(`<%(B>A)P>$%2,'H&TP)R`'(
M1HT$`$R)!P-O"`-?$`-W&`-7($B);PA(B5\02(EW&$B)5R!(@<00`@``6UW#
M#Q]$``!,B60DX$R)?"3X28G\2(E<)-!(B6PDV$F)]TR);"3H3(ET)/!(@^PX
M2(7_=2LQP$B+7"0(2(ML)!!,BV0D&$R+;"0@3(MT)"A,BWPD,$B#Q#C#9@\?
M1```3(LU,8D@`$V%]G3)#[8'/#UT783`28G]=%9)@\4!00^V10`\/70$A,!U
M[T4IY4F+'DB%VW2?36/M3(GU#Q]``$R)ZDR)YDB)W^ABY?__A<!U!T*`/"L]
M=!](@\4(2(M=`$B%VW7:9I#I:/___P\?`$4Q[>NY#Q\`3"GU2HU$*P%(P?T#
M08DOZ4O___]F9F8N#Q^$``````!(@^P8,<!(C70D#.@`____2(/$&,-F9BX/
M'X0``````$B#[`B+!5Z((`"#^/]T"4B#Q`C##Q]``#'`OX1=0`#HO/___TB%
MP'0?#[8`A,!T&#PP#Y7`#[;`B04JB"``2(/$",,/'T0``#'`Z^P/'T``54B)
M_5-(@^P82(U<)`SK($AC1"0,2,'@`T@#!1"((`!(@\`(2(L02(722(E0^'7P
M,<!(B=Y(B>_H8_[__TB%P'7.2(/$&%M=PP\?@`````!(@^P(,?_H'>;__XLX
MZ";D__^^_____TB)Q^A)X___,?_H`N;__XLXZ`OD__\QTKY`/D``2(G'2(/$
M".DXYO__4S'_Z.#E__^+..CIX___2(G'Z)'A__](BP`Q_TB+6`CHP^7__XLX
MZ,SC__](B<?H!.+__P^V`#'_B$,@Z*?E__^+..BPX___2(G'Z%CA__](BP`Q
M_TB+6`CHBN7__XLXZ)/C__](B<?HV^'__TB+`#'_#[=`(&8E_P%FB4,BZ&7E
M__^+..ANX___2(G'Z!;A__](BP`Q_TB+6`CH2.7__XLXZ%'C__\QTKX-7T``
M2(G'Z*+D__\Q_TB)0RCH)^7__XLXZ##C__](B<?HV.#__TB+`#'_2(M8".@*
MY?__BSCH$^/__TB)Q^@KX?__2(L`,?](B4,PZ.WD__^+..CVXO__2(G'Z)[@
M__](BP`Q_TB+6`CHT.3__XLXZ-GB__](B<?HP>/__S'22(,X`'0@,?_HLN3_
M_XLXZ+OB__](B<?HH^/__TB+`$B+D*@```!(B5,X,?_HCN3__XLXZ)?B__](
MB<?H/^#__TB+`#'_2(M`"$C'0$``````Z&GD__^+..ARXO__2(G'Z!K@__](
MBP`Q_TB+0`A(QT!(`````.A$Y/__BSCH3>+__TB)Q^CUW___2(L`,?](BU@(
MZ"?D__^+..@PXO__2(G'Z)CC__](BP!(B4-06\,/'X``````059!54%454B)
M_5-(@>R0````2(7_=`6`/P!U%$B!Q)````!;74%<05U!7L,/'T``Z'/B__](
MA<!(B<-TWP\?`$B)W^C`W___2(7`#X2O````3(UP"`^V%1,=```/MD`(.=`/
MA+@````/MA7_'```.=`/A,D```!(B>_H:>#__TR)]TF)Q.A>X/__08U\!`)(
M8__H\>#__TR)\4B)QTF)Q$B)ZKZ174``,<#H2>#__TB)XDR)YK\#````Z!GC
M__^#^/]T%0^W1"00)0#P```]`$````^$EP```$R)Y^C7W___3(GGZ/_>__](
MB=_H%]___TB%P`^%5____V8/'T0``$B)W^B0XO__2(GOZ"CC__](@<20````
M6UU!7$%=05[#00^V5@$Z%44<```/A`_____I,O___V8N#Q^$``````!!#[9&
M`3H%)!P```^%)O___T$/MD8".@44'```#X3>_O__Z1#___]F#Q^$``````!,
MB>?HB/[__^ED____#Q\`4TB)^S'_Z'WB__^+..B&X/__2(G'Z'[A__](B=Y(
MB<*_`P```.B^X/__A<!T"C'`6\-F#Q]$```Q_^A)XO__BSCH4N#__TB)Q^A*
MX?__#[=`$"4`\```/0!```!T)C'_Z"/B__^+..@LX/__2(G'Z"3A__\/MT`0
M)0#P```]`*```'6J2(G?O@(```#H!][__X7`#Y3`#[;`6\,/'T0``$B)7"30
M2(EL)-@QP$R)9"3@3(EL).A(B?-,B70D\$R)?"3X2(/L2(`^/4F)_`^4P$@!
MPTB)W^B-WO__2(UT)`Q!B<5,B><QP.C#^?__2(7`2(G%=%M(B<?H:][__T2)
MZD@YT`^"K0$```\?@``````/M@-(@\,!B$4`2(/%`83`=>XQP$B+7"082(ML
M)"!,BV0D*$R+;"0P3(MT)#A,BWPD0$B#Q$C#9@\?A```````2(L]Z8(@`#'M
MOA````!(@S\`2(GX="!F#Q^$``````!(@\`(@\4!2(,X`'7SC74"2&/V2,'F
M`XL%\X(@`(7`="?H,MW__TB%P$F)QDB)!9V"(`!,8_UU2[C_____Z7+___]F
M#Q]$``!(B??'!;N"(``!````Z#[>__](A<!)B<9TUDQC_4B+-62"(`!(B<=*
MC13]`````.A,W/__3(DU38(@`$O'1/X(`````(EL)`Q!#[84)(#Z/0^$L0``
M`(323(G@=0_II0```&8/'T0``(32=`Y(@\`!#[80@/H]9I!U[HGM12GE2,'E
M`T@#+?Z!(`!!C7P%`NB\W?__2(7`2(E%``^$3____XM4)`Q(BP7<@2``2(L4
MT$$/M@0DA,"(`G0D/#UT($F#Q`'K!P\?`#P]=!-!#[8$)$B#P@%)@\0!A,"(
M`G7IQ@(]2(/"`6:0#[8#2(/#`8@"2(/"`83`=>_I;/[__XML)`SI0?___TR)
MX.EK____9@\?A```````05=!5D%528G]051!O*%=0`!54[N774``2(/L2$R+
M/?4:``!(QT0D$*%=0`!(QT0D&)==0`!(C6PD($C'1"0@I%U``$C'1"0HFEU`
M`$C'1"0PGUU``$C'1"0X#5]``.LG3(GN2(G'2(D$).CYWO__2(7`=$R`.P!T
M-$B+10!)B=Q(@\4(2(G#,<!,B>?H/_C__TB%P'0%@#@`=<4QP$R)[DR)Y^@H
M_?__@#L`=<Q(@\1(6UU!7$%=05Y!7\,/'T``3(GOZ-#;__],B?](B40D".C#
MV___3(L$)$F)QDR)Q^BTV___2(M4)`A*C7PR`4@!Q^A"W/__3(L$)$F)QDB)
MQTR)^4R)ZKZ\7D``,<#HEMO__TR)]DR)YS'`Z+'\___I4/___V9F9BX/'X0`
M`````$B#[#B_L5U``&1(BP0E*````$B)1"0H,<!(BP68&0``2(D$)$B+!949
M``!(B40D"$B+!9$9``!(B40D$$B+!8T9``!(B40D&`^W!8D9``!FB40D(#'`
MZ+7W__\QP+^Z74``Z*GW__\QP+_"74``Z)WW__\QP+_+74``Z)'W__\QP+_2
M74``Z(7W__\QP+_B74``Z'GW__\QP+_N74``Z&WW__\QP+^$74``Z&'W__\Q
MP+_W74``Z%7W__\QP+\!7D``Z$GW__\QP+\+7D``Z#WW__\QP+\87D``Z#'W
M__\QP+\A7D``Z"7W__\QP+\L7D``Z*GV__](A<!T#TB)QK_W74``,<#HE?O_
M_S'`OSU>0`#HB?;__TB%P'0/2(G&OT]>0``QP.AU^___,<"_6EY``.AI]O__
M2(7`=#Q(B<:_[EU``#'`Z%7[__\QP+Z&7D``O])=0`#H1/O__TB+1"0H9$@S
M!"4H````=5I(@\0XPP\?@``````QP+]J7D``Z!SV__](A<!T%TB)QK^$74``
M,<#H"/O__^NQ9@\?1```2(UT)!&_>UY``+D*````\Z9UF$B-="0;OX1=0``Q
MP.C<^O__ZX7H?=O__P\?1```2(/L".C_VO__B<?HN-G__TB)PC'`2(72=`-(
MBP)(@\0(PV9F9F9F+@\?A```````2(7_4TB)^W17@#\`=%+H5=G__TB-1`/_
M2#G##X/5````2(L]N!<```^V"`^V%SC1=`KK4`\?0``X"'5(2(/H`4@YPW+S
M2#G8=4X/M@`Z!P^$@P```%OI#=O__P\?1```OP(```#HGMG__TB%P'0%9L<`
M+@!;PV8N#Q^$```````X$'3!2(/H`4@YPW+S2#G8=+AF#Q]$``!(@^@!2#G#
M<P</MA`Z%W3P2(G",<!(*=I(C4H"2('Y``0``'>W2(G>2(/"`;]`QF``Z*K;
M__^X0,9@`%O##Q\`OP(```#H)MG__TB)PC'`2(72=(AFQP(N`$B)T%O#2(L]
MXQ8``.E#____9F9F9F8N#Q^$``````!52(G]4TB#[`CHXO[__P^V"$B)PX3)
M="I(BQ6Q%@``#[8R2(U0`68N#Q^$``````!`./$/M@I(#T3:2(/"`83)=>XQ
MP.AG]/__A<!T'4B%[708@'T``'02OHA>0`!(B=_HP]K__T@YV'0'2(/$"%M=
MPTB#Q`A(B>];7>GQ]O__D%-(@^P@B7PD'$B)="002(U\)!Q(B50D"$B-="00
M2(U4)`CHL=K__[I(($``O]@A0`!(B=;H!Q,``#'_Z.C7__^`.`!U-NC.U___
M2(7`2(D%O(`@``^$M@$``$B)Q^AFV/__,?_HC]K__XLXZ)C8__](B<?HP-G_
M_\8``#'_Z';:__^+..A_V/__2(G'Z'?:__^`"`(Q_^A=VO__BSCH9MC__TB)
MQ^A>VO__@`@!BWPD'(/'!4AC_TB%_P^(&`$``/)(#RK'\@]8!;,6``!F#RX%
MLQ8```^'/P$``$C!YP/H=-G__TB+="002(D%.(`@`$B+%DC'0`B-7D``2,=`
M$.!@0`!(QT`8D%Y``$B)$(M\)!S'!02`(``$````@_\!?B.Z"````+D!````
M#Q]$``!(BQP6@\$!2(E<$!A(@\((.<]_[(U7!$4QP$B)P;X@7$``2&/22,=$
MT/@`````C5<#2(L]J'\@`.A[U?__A<")PW0]2(L]EG\@`.@)V/__,<"_XEU`
M`.B%\O__2(7`=#!(BSUY?R``Z"S5___HM];__XG82(/$(%O##Q^``````$B+
M/5E_(`#HW-7__XG#Z[-(BSU1?R``2(7_="GHK_W__^N]#Q]$``!(B?A(B?I(
MT>B#X@%("=#R2`\JP/(/6,#IT/[__[_N74``Z!'R__](A<!(B<=(B04,?R``
M=(+KO+\!````Z%[5__^^\,5@`+^474``,<#H_=?__P\?1```05=!5D%528GU
M051)B?R_[EU``%532('L*`0``&1(BP0E*````$B)A"08!```,<#HK/'__TB+
M'>43``!,B>=(B<5(B=[H+]C__TB%P'0[3(GFOPM>0``QP.B#]O__2(N4)!@$
M``!D2#,4)2@```!,B>`/A6\!``!(@<0H!```6UU!7$%=05Y!7\-,B>?H%]7_
M_TB+-9`3``!,B>^)1"0,Z!36__](A<!)B<9THHM4)`Q,C6PD$$&_CUU``(/"
M`8E4)`QF#Q]$``!!@#X`30]$]TB%[7033(GV2(GOZ+C6__^%P`^$L0```$R)
M]^BXU/__2&/000^V5!;_.A-U)8U0_TACTDF-%!9F#Q^$```````/MDK_Q@(`
M@^@!2(/J`3H+=.X#1"0,/?\#```/CQW___]-B>!(B=E,B?*^O%Y``$R)[S'`
MZ&_4__\Q_^AXU___BSCH@=7__TB)Q^AYUO__3(GN2(G"OP,```#H*=?__X7`
M=28Q_^A.U___BSCH5]7__TB)Q^A/UO__#[=`$"4`\```/0"```!T'TB+-8@2
M```Q_^@1U?__2(7`28G&#X45____Z9;^__^^`0```$R)[^@3T___A<!UT$R)
M[K\+7D``Z`KU__],B>_HRM7__TF)Q.EW_O__Z)W5__\/'T0``$%7059!54%4
M55-(B?N_[EU``$B![!B"``!D2(L$)2@```!(B80D"((``#'`2,>$)``!``"3
M7D``2,>$)`@!``";7D``2,>$)!`!``"/74``2,>$)!@!```-7T``2,>$)-``
M``!/7D``2,>$)-@```!(7D``2,>$).````"@7D``2,>$).@```"67D``2,>$
M)/````"H7D``2,>$)/@````-7T``2,>$)"`!``"L7D``2,>$)"@!``"Q7D``
M2,>$)#`!```-7T``Z"/O__](A<!T"8`X``^%I0,``#'`#Q\`Z#OY__](A<!)
MB<</A+<#``!!#[8O0(3M="KH2=/__TR)^F8/'T0``$B+"$@/ONWV!&D(=0/&
M`E](@\(!#[8J0(3M=>1(C:PDV````+]/7D``ZQ8/'T0``$B+?0!(@\4(@#\`
M#X3G`@``,<#HH.[__TB%P$F)Q'3@2(G'Z/#R__^%P'343(GGZ$S4__](A<!)
MB<9TQ$R)]^@\TO__3(G_2(G%Z#'2__^)ZD2-I`($!```36/D3(GGZ+S2__],
MB>=(B<7HL=+__TR++8(0``!(B<=)B<1-B?E!N(A>0`!,B?*^NEY``#'`3(GI
MZ/G1__^^P`$``$R)Y^A,U/__@_C_#X3+`0``2(U4)$!,B>:_`P```.A!T___
M@_C_#X0>"```#[=$)%`E`/```#T`0```#X73`0``1(MT)%CH"=/__T$YQ@^%
MP`$```^W1"10)?\!```]P`$```^%JP$``#'`OYI=0`#HI^W__TB%P`^$G@(`
M`$B)Q^A>T___2(L[2(G&Z*O[__](A<!)B<8/A'\"``!,B??H/]'__X/X`WY:
M2&/0O\->0`"Y!0```$F-=!;\\Z9U1(/X!'01@^@$2)A!#[9$!O]!.D4`=2Y(
MBUL(2(7;="5(B=_H_=#__TB#^`-V%TB-=`/\O\A>0`"Y!0```/.F=`</'T``
M3(GS,<!)B>[H*^W__X7`=18Q]DB)W^AETO__A<")1"0L#X7Y`0``OH9>0`"_
MA%U``#'`Z.#Q___HX]+__T&Y#5]``$&)P$R)Z4R)XK[A7D``2(GO,<`QV^B3
MT/__ZSYF#Q^$``````#H(]#__X,X$74]@\,!Z*;2__]!B=E!B<!,B>E,B>*^
M[UY``$B)[S'`2,<$)`U?0`#H4]#__[[``0``2(GOZ*;2__^#^/]TN4R)Y^@I
MS___2(GNO^Y=0``QP.A2\?__2(GOZ'KS___K7`\?A```````Z+//__]$BP!!
M@_@1#Q]```^$'_[__TB+$TB+/<AT(`!,B>&^D%]``#'`13'VZ(;0___K(`\?
M0`!(BQ-(BSVF="``3(GAO@A@0``QP$4Q]NADT/__2(N4)`B"``!D2#,4)2@`
M``!,B?`/A94&``!(@<08@@``6UU!7$%=05Y!7\-,C:0D"`$``+V37D``ZQ.0
M28LL)$F#Q`B`?0``#X0B_?__2(GO13'VZ//O__^%P'3?2(GOZ$_1__](A<!)
MB<9TS^G^_/__9BX/'X0``````$B)QTB)1"00Z)/R__](BT0D$$B)Q^@>T?__
M28G&Z6+___]F#Q]$``!(C:PD*`$``+^L7D``#Q\`,<#H,>O__TB%P'042(G'
MZ.S0__](A<!)B<</A1G\__](BWT`2(/%"(`_`'730;\`7T``Z33\__],BS/I
M>?W__[H"````2,?&[O___XG'Z*W/__],C;PD0`$``(M\)"RZ!@```$R)_N@D
MT/__@+PD0`$```!U#H"\)$$!``!##X0+!0``BWPD+#'2NXFKS>\Q]NAJS___
M2(F<)$B!``!(C9PD0($``+G^W+J8NO#ATL-(QX0D0($```$C16=(B8PD4($`
M`$B->SA(QX0D6($``'94,A!(B90D8($``$C'A"1H@0```````$C'A"1P@0``
M`````,>$)+B!````````2(E\)#`/'T``BWPD++H`@```3(G^Z'?/__^%P(E$
M)"`/CI@!``!(8U0D($B+M"1H@0``2(N$)'"!``"+O"2X@0``C0S62#GQ2(F,
M)&B!``!,B?Y(@]``2,'J'4B)A"1P@0``2`&4)'"!``"%_W1JN4`````I^3E,
M)"!(8_\/3DPD($@#?"0P2&/!B4PD&$B)PDB)1"0XZ';/__^+A"2X@0``BTPD
M&`'(@_A`B80DN($```^%4?___TB+5"0X2(G?*4PD($F--!=(B70D&.@'TO__
M2(MT)!AFD(-\)"`_#XZ[````,<`/'P!(BQ0&2(G?2(F4)'B!``!(BU0&"$B)
ME"2`@0``2(M4!A!(B90DB($``$B+5`882(F4))"!``!(BU0&($B)E"28@0``
M2(M4!BA(B90DH($``$B+5`8P2(F4)*B!``!(BU0&.$B)1"002(ET)!A(B90D
ML($``.AWT?__2(M$)!"+5"0@2(MT)!A(@\!`*<*#^C\/CVK___^+5"0@@^I`
MB='!Z0:)R,'A!DC!X`8IRDB-=#!`B50D($AC5"0@2(M\)##H8\[__XM\)"")
MO"2X@0``Z4O^__^+?"0LZ/K.__],B[PD:($``$R+A"1P@0``3(GX2,'H`X/@
M/TACT(/``8/X.,:$%'B!``"`#X\F`@``NC@````Q]DR)1"00*<)(F$B-?`,X
M2&/2Z`S-__],BT0D$$R)P$B)WT2(O"2W@0``2,'H&$2(A"2S@0``2(V<),"!
M``"(A"2P@0``3(G`2,'H$(B$)+&!``!,B<!(P>@(B(0DLH$``$R)^$C!Z!B(
MA"2T@0``3(GX2,'H$(B$)+6!``!,B?A,C;PD\8$``$C!Z`B(A"2V@0``Z$/0
M__](BX0D0($``$B)P8B$)/.!``!(P>D8B<J(C"3P@0``2(G!2,'I$(B,)/&!
M``!(B<%(BX0D2($``$C!Z0B(C"3R@0``2(G!B(0D]X$``$C!Z1B(C"3T@0``
M2(G!2,'I$(B,)/6!``!(B<%(BX0D4($``$C!Z0B(C"3V@0``2(G!B(0D^X$`
M`$C!Z1B(C"3X@0``2(G!2,'I$(B,)/F!``!(B<%(BX0D6($``$C!Z0B(C"3Z
M@0``2(G!B(0D_X$``$C!Z1B(C"3\@0``2(G!2,'I$(B,)/V!``!(B<%(BX0D
M8($``$C!Z0B(C"3^@0``2(G!B(0D`X(``$C!Z1B(C"0`@@``2(G!2,'I$(B,
M)`&"``!(B<%(B=A(P>D(2(/`*(B,)`*"``!(B40D(.L.9@\?1```00^V%TF#
MQP%(B=\QP`^VTK[<7D``2(/#`N@JRO__2#M<)"!UVTR-A"3`@0``QH0DZ($`
M``!!N0U?0`!,B>E,B>*^S5Y``$B)[S'`Z/C)___ILOG__TR-2SBZ0````#'V
M*<)(F$R)1"0028T\`4ACTDR)3"08Z-[*__](B=_HCL[__TR+3"08N0<````Q
MP$R)S_-(JTR+1"00Z;/]___H1<G__TB+$T2+`$R)X4B+/65N(`"^T%]``#'`
M13'VZ";*___IO?G__X"\)$(!``!!#X7G^O__@+PD0P$``$,/A=GZ__^`O"1$
M`0``2`^%R_K__X"\)$4!``!%#X6]^O__BWPD++H"````2,?&QO___^@DRO__
MBWPD++HI````3(G^Z*/*__]!N0U?0`!-B?CI"/___^C@RO__#Q^$``````!!
M53'_05154TB#[`CH!\S__XLXZ!#*__](B<?H2,G__[_274``Q@`!,<#H`>7_
M_TB%P'0)@#@Q#X2C`@``,<"0Z$OM__\Q_^C,R___BSCHU<G__[D+````N@$`
M``"^!U]``$B)Q^A^R/__2(7`#X2V````2(M`$#';O0@```!,BV`HBP6X<2``
M@_@!?S?IC````&8/'T0``$F+=1!(BP6E<2``2(L\*.@\RO__A<!U:(/#`8L%
MAW$@`$B#Q0B-4P$YPGU:,?_H3<O__XLXZ%;)__\QR8G:3(GF2(G'Z'?)__](
MA<!T,DR+*$'V10T$=:@Q_^@AR___BSCH*LG__TR)[KD"````,=)(B<?H:,O_
M_TB)QNN'#Q\`BP4B<2``C5#_.=H/A$\!```Q_^CHRO__BSCH\<C__[D%````
MN@$```"^#%]``$B)Q^B:Q___2(7`2(G#=#9(BT`0,?](BRCHM,K__XLXZ+W(
M__^Z#E]``$B)QTB)[NB=Q___2(M#$$B+&/9##D`/A30!```Q_^B%RO__BSCH
MCLC__[D%````N@$```"^*EY``$B)Q^@WQ___2(7`2(G#=#LQP+\+7D``Z&OC
M__](A<!)B<0/A"<!``!(BT,0,?](BRCH.<K__XLXZ$+(__],B>)(B>Y(B<?H
M),?__S'_Z!W*__^+..@FR/__2(G'Z%['__\Q_\8``.@$RO__BSCH#<C__TB)
MQ^@5RO__O^Y=0`!(QP``````,<#H^N+__TB%P$B)!?AO(``/A,$```"^[0$`
M`$B)Q^@5R?__@_@1=`Z%P'0*@_C_D`^%"`$``$B#Q`A;74%<05W##Q^`````
M`(/X`0^.J/[__[L!````9BX/'X0``````#'_@\,!Z'[)__^+..B'Q___3(GF
M2(G'Z"S&__\Y'8YO(`!_W.EP_O__#Q^``````#'_Z%')__^+..A:Q___2(G>
M2(G'Z._'___IKO[__V:0@'@!``^$6_W__V8/'T0``.E(_?__#Q\`2(L%26\@
M`$R+(.G*_O__2(L].F\@`.@M\O__2(D%'F\@`$B+0Q!(BRTC;R``3(L@0?9$
M)`T$='])BT0D$$B)[DB)Q^CXQO__B<5(BT,02(L8]D,-!'0^2(M#$$B)PDB+
M!>MN(`")Z;\P8$``2(LP,<#HVL?__XG!2(L%T6X@`$B+%;IN(`"_8&!``$B+
M,#'`Z+O'__\Q_^B$R/__BSCHC<;__[D"````,=)(B=Y(B<?HR\C__^ND,?_H
M8LC__XLXZ&O&__^Y`@```#'23(GF2(G'Z*G(___I8?___V9F9BX/'X0`````
M`$B#[`@Q_^@MR/__BSCH-L;__[D37T``NL@A0`"^'5]``$B)QTB#Q`CIR\?_
M_P\?`$B#[`@Q_^C]Q___BSCH!L;__TB)Q^BV____,?_HY\?__XLXZ/#%__]!
MN`U?0`!%,<FZ$%A``$R)P;XY7T``2(G'2(/$".E^Q?__D)"0D)"02(L%P68@
M`$B%P'0(2(L(Z13$__\QR>OWD)"0D)"0D)#SPV9F9F9F+@\?A```````2(EL
M)-A,B60DX$B-+6-D(`!,C25<9"``3(EL).A,B70D\$R)?"3X2(E<)-!(@^PX
M3"GE08G]28GV2,']`TF)U^C+PO__2(7M=!PQVP\?0`!,B?I,B?9$B>]!_Q3<
M2(/#`4@YZW+J2(M<)`A(BVPD$$R+9"083(ML)"!,BW0D*$R+?"0P2(/$.,.0
MD)"0D)"054B)Y5-(@^P(2(L%V&,@`$B#^/]T&;L8P6``#Q]$``!(@^L(_]!(
MBP-(@_C_=?%(@\0(6\G#D)!(@^P(Z'_'__](@\0(PP`````````````!``(`
M4$%27T-,14%.`"XN`"5S+R5S`$Q)0E!!5$@`1%E,1%],24)205)97U!!5$@`
M4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)
M6D5$`%!!4E]34$%73D5$`%!!4E]414U0`%!!4E]$14)51P!005)?0T%#2$4`
M4$%27U!23T=.04U%`%!!4E]!4D=#`%!!4E]!4D=67S``4$%27T=,3T)!3%]$
M14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?
M5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!P87(M`"UE`"TM
M`$,Z7%1%35``+W1M<`!414U01$E2`%1-4`!54T52`%5315).04U%`"5S)7,E
M<R5S`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E,#)X`"5S)7-T96UP+25U
M)7,`)7,E<W1E;7`M)74M)74E<P!365-414T`05)'5@`8`'!E<FP`<&5R;'AS
M:2YC`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!
M4CHZ0D]/5``O`#H`````````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@
M("`@("```````````$Y?0```````4%]````````E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````
M````)7,Z('-T870@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D
M("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@
M=6YS869E"@``)7,Z(&5X96-U=&EO;B!O9B`E<R!F86EL960@+2!A8F]R=&EN
M9R!W:71H("5I+@H`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@=&5M<&]R87)Y
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@+2!A8F]R=&EN9R!W:71H("5I+@H`
M`````````````````````,!#<&%R+G!L````````````````````````````
M```````C(2]U<W(O8FEN+W!E<FP*979A;"`G97AE8R`O=7-R+V)I;B]P97)L
M("`M4R`D,"`D>S$K(B1`(GTG"B`@("!I9B`P.R`C(&YO="!R=6YN:6YG('5N
M9&5R('-O;64@<VAE;&P*"G!A8VMA9V4@7U]P87)?<&P["@HC("TM+2!4:&ES
M('-C<FEP="!M=7-T(&YO="!U<V4@86YY(&UO9'5L97,@870@8V]M<&EL92!T
M:6UE("TM+0HC('5S92!S=')I8W0["@HC;&EN92`Q-3@*"FUY("@D<&%R7W1E
M;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?
M0TQ%04Y]*2!["B`@("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@
M;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M
M<"D["B`@("!O=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B
M?2D["B`@("!&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@
M<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*("`@(')M9&ER("1P87)?
M=&5M<#L*("`@(",@1&]N)W0@<F5M;W9E('1O<&1I<B!B96-A=7-E('1H:7,@
M8V%U<V5S(&$@<F%C92!W:71H(&]T:&5R(&%P<',*("`@(",@=&AA="!A<F4@
M=')Y:6YG('1O('-T87)T+@H*("`@(&EF("@M9"`D<&%R7W1E;7`@)B8@)%Y/
M(&YE("=-4U=I;C,R)RD@>PH@("`@("`@(",@4V]M971H:6YG('=E;G0@=W)O
M;F<@=6YL:6YK:6YG('1H92!T96UP;W)A<GD@9&ER96-T;W)Y+B`@5&AI<PH@
M("`@("`@(",@='EP:6-A;&QY(&AA<'!E;G,@;VX@<&QA=&9O<FUS('1H870@
M9&ES86QL;W<@=6YL:6YK:6YG('-H87)E9`H@("`@("`@(",@;&EB<F%R:65S
M(&%N9"!E>&5C=71A8FQE<R!T:&%T(&%R92!I;B!U<V4N(%5N;&EN:R!W:71H
M(&$@8F%C:V=R;W5N9`H@("`@("`@(",@<VAE;&P@8V]M;6%N9"!S;R!T:&4@
M9FEL97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@8GD@=&AI<R!P<F]C97-S+@H@
M("`@("`@(",@1&]N)W0@9&\@86YY=&AI;F<@;VX@5VEN9&]W<R!B96-A=7-E
M(&]U<B!P87)E;G0@<')O8V5S<R!W:6QL"B`@("`@("`@(R!T86ME(&-A<F4@
M;V8@8VQE86YI;F<@=&AI;F=S('5P+@H*("`@("`@("!M>2`D=&UP(#T@;F5W
M($9I;&4Z.E1E;7`H"B`@("`@("`@("`@(%1%35!,051%(#T^("=T;7!86%A8
M6"<L"B`@("`@("`@("`@($1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M
M92@D=&]P9&ER*2P*("`@("`@("`@("`@4U5&1DE8(#T^("<N8VUD)RP*("`@
M("`@("`@("`@54Y,24Y+(#T^(#`L"B`@("`@("`@*3L*"B`@("`@("`@<')I
M;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[
M(&1O"B`@(')M("UR9B`G)'!A<E]T96UP)PH@("!I9B!;(%PA("UD("<D<&%R
M7W1E;7`G(%T[('1H96X*("`@("`@(&)R96%K"B`@(&9I"B`@('-L965P(#$*
M("`@>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA
M;64@+B`B)PHB.PH@("`@("`@("`@("!C:&UO9"`P-S`P+"1T;7`M/F9I;&5N
M86UE.PH@("`@("`@(&UY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D
M978O;G5L;"`R/B8Q("8G.PH@("`@("`@(&-L;W-E("1T;7`["B`@("`@("`@
M<WES=&5M*"1C;60I.PH@("`@("`@(&]U=',H<7$H4W!A=VYE9"!B86-K9W)O
M=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"B`@("`@("`@("`@
M("`N("1T;7`M/F9I;&5N86UE*3L*("`@('T*?2!]"@I"14=)3B!["B`@("!)
M;G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A<E]I;FET7V5N=B@I.PH*:68@
M*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]
M("D@>PH@("`@0$%21U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@
M+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*("`@("0P(#T@)$5.5GM005)?05)'
M5E\P?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y<R`E14Y6*2!["B`@("`@("`@
M9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?+SL*("`@('T*?0H*;7D@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*"B,@9FEX("1P<F]G;F%M92!I
M9B!I;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N9FEG(#T@*`H@("`@<&%T:%]S
M97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"B`@("!?
M97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO
M(#\@)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O
M7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*"E]S971?<')O9VYA;64H
M*3L*7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I8R!S=')I;F<@8VAE8VMI;F<@
M86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S('M[>PIM>2`H)'-T87)T
M7W!O<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C86P@)%-)1WM?7U=!4DY?7WT@
M/2!S=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE('1Y<&4L(&=E="!S=&%R="!O
M9B!D871A('-E8W1I;VX@>WM["B`@("!O<&5N(%]&2"P@)SPG+"`D<')O9VYA
M;64@;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(*3L*"B`@("!M>2`D8G5F.PH@
M("`@<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#@["B`@
M("!L87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*"B`@("!S965K
M(%]&2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!S965K
M(%]&2"P@+3$R("T@=6YP86-K*").(BP@)&)U9BDL(#(["B`@("!R96%D(%]&
M2"P@)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*
M("`@(",@?7U]"@H@("`@(R!%>'1R86-T:6YG(&5A8V@@9FEL92!I;G1O(&UE
M;6]R>2![>WL*("`@(&UY("5R97%U:7)E7VQI<W0["B`@("!W:&EL92`H)&)U
M9B!E<2`B1DE,12(I('L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@
M("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@
M("`@(&UY("1F=6QL;F%M92`]("1B=68["B`@("`@("`@;W5T<RAQ<2A5;G!A
M8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PH@("`@("`@(&UY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["B`@("`@("`@;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]
M?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*("`@("`@("!R96%D(%]&2"P@
M)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["@H@("`@("`@(&EF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^
M("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@("`@("`@("`@("!M>2`H)&]U
M="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*("`@("`@
M("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U
M="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@
M("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("`@("`@8VAM;V0@,#<U
M-2P@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*("`@
M("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@
M)&9U;&QN86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H("1F=6QL;F%M
M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@
M*2!["B`@("`@("`@("`@(",@<VAO=6QD(&)E(&UO=F5D('1O(%]T96UP9FEL
M92@I"B`@("`@("`@("`@(&UY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0
M?2\D8F%S96YA;64D97AT(CL*("`@("`@("`@("`@;W5T<R@B4TA,24(Z("1F
M:6QE;F%M95QN(BD["B`@("`@("`@("`@(&]P96X@;7D@)&]U="P@)SXG+"`D
M9FEL96YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1O=70I
M.PH@("`@("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@(&-L
M;W-E("1O=70["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@
M("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0H@("`@("`@("`@("`D4$%2
M.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*("`@("`@("`@
M("`@("`@(&)U9B`]/B`D8G5F+`H@("`@("`@("`@("`@("`@8W)C(#T^("1C
M<F,L"B`@("`@("`@("`@("`@("!N86UE(#T^("1F=6QL;F%M92P*("`@("`@
M("`@("`@?3L*("`@("`@("!]"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0[
M"B`@("!]"B`@("`C('U]?0H*("`@(&QO8V%L($!)3D,@/2`H<W5B('L*("`@
M("`@("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["@H@("`@("`@(')E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*"B`@("`@("`@;7D@)&9I
M;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@
M>PH@("`@("`@("`@("!M>2`D:V5Y.PH@("`@("`@("`@("!F;W)E86-H("AK
M97ES("5R97%U:7)E7VQI<W0I('L*("`@("`@("`@("`@("`@(&YE>'0@=6YL
M97-S("]<421M;V1U;&5<120O.PH@("`@("`@("`@("`@("`@)&ME>2`]("1?
M.R!L87-T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["B`@("`@("`@?2!O
M<B!R971U<FX["@H@("`@("`@("1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D
M9FEL96YA;64O)&UO9'5L92(["@H@("`@("`@(&EF("@D14Y6>U!!4E]#3$5!
M3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["B`@("`@("`@("`@
M(&UY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["B`@
M("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<')I;G0@)&9H
M("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@('-E96LH)&9H+"`P+"`P
M*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"B`@("`@("`@
M96QS92!["B`@("`@("`@("`@(&UY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I
M;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PH@("`@("`@("`@("!I9B`H
M)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@
M("`@("`@("`@('!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@
M("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PH@("`@("`@
M("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@
M("`@("`@?0H*("`@("`@("!D:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C
M86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@('TL($!)3D,I.PH*("`@(",@
M3F]W(&QO860@86QL(&)U;F1L960@9FEL97,@>WM["@H@("`@(R!I;FET:6%L
M:7IE('-H87)E9"!O8FIE8W0@<')O8V5S<VEN9PH@("`@<F5Q=6ER92!84TQO
M861E<CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@0V%R
M<#HZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(%!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"B`@("`C(&YO=R!L970G
M<R!T<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE<R!F<F]M('=I=&AI;@H@("`@
M<F5Q=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO860@<F5S="!O9B!T:&4@9W)O
M=7`@:6X*("`@('=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R
M97%U:7)E7VQI<W0I6S!=*2!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP
M;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!U
M;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!
M3B\I('L*("`@("`@("`@("`@(R!R97%U:7)E(&UO9'5L97,L(&1O(&]T:&5R
M(&5X96-U=&%B;&4@9FEL97,*("`@("`@("`@("`@:68@*"1F:6QE;F%M92`]
M?B`O7"YP;6,_)"]I*2!["B`@("`@("`@("`@("`@("!R97%U:7)E("1F:6QE
M;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@("`@(",@4VMI<"!!8W1I=F53=&%T92=S('-I=&5C=7-T;VUI>F4N
M<&P@9FEL93H*("`@("`@("`@("`@("`@(&1O("1F:6QE;F%M92!U;FQE<W,@
M)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PH@("`@("`@("`@
M("!]"B`@("`@("`@?0H@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1F
M:6QE;F%M97T["B`@("!]"@H@("`@(R!]?7T*"B`@("!L87-T('5N;&5S<R`D
M8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@("1S=&%R=%]P;W,@/2`H=&5L;"!?
M1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U;65N="!P<F]C97-S:6YG('M[>PIM
M>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H
M95]N86UE*3L*"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET
M:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0H*)'%U:65T
M(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PHC($1O;B=T('-W86QL;W<@
M87)G=6UE;G1S(&9O<B!C;VUP:6QE9"!E>&5C=71A8FQE<R!W:71H;W5T("TM
M<&%R+6]P=&EO;G,*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G
M+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["B`@("!M>2`E9&ES=%]C;60@
M/2!Q=R@*("`@("`@("!P("`@8FQI8E]T;U]P87(*("`@("`@("!I("`@:6YS
M=&%L;%]P87(*("`@("`@("!U("`@=6YI;G-T86QL7W!A<@H@("`@("`@(',@
M("!S:6=N7W!A<@H@("`@("`@('8@("!V97)I9GE?<&%R"B`@("`I.PH*("`@
M(",@:68@=&AE(&%P<"!I<R!I;G9O:V5D(&%S(")A<'!N86UE("TM<&%R+6]P
M=&EO;G,@+2UR975S92!04D]'4D%-($!04D]'7T%21U8B+`H@("`@(R!U<V4@
M=&AE(&%P<"!T;R!R=6X@=&AE(&=I=F5N('!E<FP@8V]D92!I;G-T96%D(&]F
M(&%N>71H:6YG(&9R;VT@=&AE"B`@("`C(&%P<"!I='-E;&8@*&)U="!S=&EL
M;"!S970@=7`@=&AE(&YO<FUA;"!A<'`@96YV:7)O;FUE;G0@86YD($!)3D,I
M"B`@("!I9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PH@
M("`@("`@('-H:69T($!!4D=6.PH@("`@("`@("1%3E9[4$%27T%04%]21553
M17T@/2!S:&EF="!`05)'5CL*("`@('T*("`@(&5L<V4@>R`C(&YO<FUA;"!P
M87)L(&)E:&%V:6]U<@H*("`@("`@("!M>2!`861D7W1O7VEN8SL*("`@("`@
M("!W:&EL92`H0$%21U8I('L*("`@("`@("`@("`@)$%21U9;,%T@/7X@+UXM
M*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*"B`@("`@("`@("`@
M(&EF("@D,2!E<2`G22<I('L*("`@("`@("`@("`@("`@('!U<V@@0&%D9%]T
M;U]I;F,L("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D
M,2!E<2`G32<I('L*("`@("`@("`@("`@("`@(&5V86P@(G5S92`D,B(["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@
M("`@("`@("`@("`@("`@=6YS:&EF="!`<&%R7V%R9W,L("0R.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G3R<I('L*("`@("`@
M("`@("`@("`@("1O=70@/2`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE
M(#T@)W-I=&4G.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D
M,2!E<2`G0B<I('L*("`@("`@("`@("`@("`@("1B=6YD;&4@/2`G86QL)SL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2![
M"B`@("`@("`@("`@("`@("`D<75I970@/2`Q.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@(&5L<VEF("@D,2!E<2`G3"<I('L*("`@("`@("`@("`@("`@
M(&]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P
M96X@;&]G.B`D(2(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@
M*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@("`@("`@)&-A8VAE7VYA;64@/2`D
M,CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@<VAI9G0H0$%21U8I.PH*
M("`@("`@("`@("`@:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["B`@
M("`@("`@("`@("`@("!D96QE=&4@)$5.5GLG4$%27U1%35`G?3L*("`@("`@
M("`@("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@("`@("`@("!R97%U:7)E
M(%!!4CHZ1&ES=#L*("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M
M9")]*"D@=6YL97-S($!!4D=6.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*("`@("`@("`@("`@("`@(&5X
M:70["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@('5N<VAI9G0@
M0$E.0RP@0&%D9%]T;U]I;F,["B`@("!]"GT*"B,@6%A8("TM(&%D9"`M+7!A
M<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T<'5T(&UO9&4@*"U/*2!H
M86YD;&EN9R![>WL*:68@*"1O=70I('L*("`@('L*("`@("`@("`C;&]C86P@
M)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G
M.PH@("`@("`@(')E<75I<F4@24\Z.D9I;&4["B`@("`@("`@<F5Q=6ER92!!
M<F-H:79E.CI::7`["B`@("!]"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6
M*3L*("`@(&UY("1Z:7`["@H*("`@(&EF("AD969I;F5D("1P87(I('L*("`@
M("`@("!O<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I
M;F0@)R1P87(G.B`D(2(["B`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@
M(&)L97-S*"1F:"P@)TE/.CI&:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL*("`@("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@
M("`@("`@("`@(&]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@
M('T*"@H@("`@;7D@)65N=B`](&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@
M("`@("`@("`D;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B`@("`@("`@("`@("1M971A(#U^("]>
M("`H6UXZ72LI.B`H+BLI)"]M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@
M3W!E;B!I;G!U="!A;F0@;W5T<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@
M/2!<-#L*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!0
M05(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM
M;V1E*%!!4BD["B`@("`@("`@9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE
M(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R
M96%T95!A=&@H)&]U="D@.PH@("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W*`H@("`@("`@("1O=70L"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H
M*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H
M*2P*("`@("`@("`P-S<W+`H@("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E
M*"1F:"D["@H@("`@)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A
M7W!O<R`Z('5N9&5F.PH@("`@<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A
M9&5R(#T@<V-A;&%R(#Q?1D@^.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)
M37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@
M('T*("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@
M("`@("!M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V
M86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY
M("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@
M("`@("!M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@
M("`@("`@("1L;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@
M)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D
M<V5T*2DI"B`@("`@("`@?65G.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A
M9&5R*3L*("`@("0O(#T@=6YD968["B`@("`C('U]?0H*("`@(",@5W)I=&4@
M8G5N9&QE9"!M;V1U;&5S('M[>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@
M("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN
M:71?9'EN86QO861E<B@I.PH@("`@("`@(&EN:71?:6YC*"D["@H@("`@("`@
M(')E<75I<F5?;6]D=6QE<R@I.PH*("`@("`@("!M>2!`:6YC(#T@<V]R="![
M"B`@("`@("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE;F=T:"@D82D*("`@("`@
M("!](&=R97`@>PH@("`@("`@("`@("`A+T)31%!!3B\*("`@("`@("!](&=R
M97`@>PH@("`@("`@("`@("`H)&)U;F1L92!N92`G<VET92<I(&]R"B`@("`@
M("`@("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD
M"B`@("`@("`@("`@("`D7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X
M<'TI.PH@("`@("`@('T@0$E.0SL*"B`@("`@("`@(R!&:6QE(&5X:7-T<R!T
M97-T(&%D9&5D('1O(&9I>"!25"`C-#$W.3`Z"B`@("`@("`@(R!&=6YN>2P@
M;F]N+65X:7-T:6YG(&5N=')Y(&EN(%\\+BXN+F%U=&\O0V]M<')E<W,O4F%W
M+UIL:6(O875T;W-P;&ET+FEX+@H@("`@("`@(",@5&AI<R!I<R!A(&)A;F0M
M86ED(&9I>"!W:71H(&YO(&1E97!E<B!G<F%S<"!O9B!T:&4@:7-S=64N"B`@
M("`@("`@(R!3;VUE8F]D>2!P;&5A<V4@9V\@=&AR;W5G:"!T:&4@<&%I;B!O
M9B!U;F1E<G-T86YD:6YG('=H870G<R!H87!P96YI;F<L"B`@("`@("`@(R!)
M(&9A:6QE9"X@+2T@4W1E9F9E;@H@("`@("`@(&UY("5F:6QE<SL*("`@("`@
M("`O7E\\*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K
M97ES("4Z.CL*("`@("`@("`D9FEL97-[)%]]*RL@9F]R('9A;'5E<R`E24Y#
M.PH*("`@("`@("!M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?
M97AT?3L*("`@("`@("!M>2`E=W)I='1E;CL*"B`@("`@("`@9F]R96%C:"`H
M<V]R="!K97ES("5F:6QE<RD@>PH@("`@("`@("`@("!M>2`H)&YA;64L("1F
M:6QE*3L*"B`@("`@("`@("`@(&9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PH@
M("`@("`@("`@("`@("`@:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD7WTI('L*("`@("`@("`@("`@("`@("`@("`D9FEL92`]("1?.PH@
M("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!E;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<
M6B]I*2!["B`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H
M)#$L("0R*3L*("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@*&TA7B]L;V%D97(O6UXO
M72LO*"XJ6UY#8UTI7%HA*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&UY
M("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B`@("`@
M("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q
M*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@96QS:68@*"UF("(D9&ER
M+R0Q(BD@>PH@("`@("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE
M*2`]("@B)&1I<B\D,2(L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@
M;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN
M960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*("`@("`@("`@
M("`@;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB
M7V5X=%Q%)"\["B`@("`@("`@("`@(&]U=',H(&IO:6X@(B(L"B`@("`@("`@
M("`@("`@("!Q<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA
M;65](#H@)&9I;&4L"B`@("`@("`@("`@("`@("!Q<2@B+BXN*0H@("`@("`@
M("`@("`I.PH*("`@("`@("`@("`@;7D@)&-O;G1E;G0["B`@("`@("`@("`@
M(&EF("AR968H)&9I;&4I*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]
M("1F:6QE+3Y[8G5F?3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E
M('L*("`@("`@("`@("`@("`@(&]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D
M:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*("`@("`@("`@("`@("`@(&)I
M;FUO9&4H1DE,12D["B`@("`@("`@("`@("`@("`D8V]N=&5N="`](#Q&24Q%
M/CL*("`@("`@("`@("`@("`@(&-L;W-E($9)3$4["@H@("`@("`@("`@("`@
M("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4I"B`@("`@("`@("`@("`@("`@("`@:68@(21%3E9[4$%27U9%
M4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PH*("`@
M("`@("`@("`@("`@(",@1&\@;F]T(&QE="!84TQO861E<B!P:6-K('5P(&%U
M=&\O*B!F<F]M(&5N=FER;VYM96YT"B`@("`@("`@("`@("`@("`D8V]N=&5N
M="`]?B!S+V=O=&\@*W)E=')Y("MU;FQE<W,@*RXJ+V=O=&\@<F5T<GD[+PH@
M("`@("`@("`@("`@("`@("`@(&EF(&QC*"1N86UE*2!E<2!L8R@B6%-,;V%D
M97(N<&TB*3L*("`@("`@("`@("`@?0H*("`@("`@("`@("`@;W5T<RAQ<2A7
M<FET=&5N(&%S("(D;F%M92(I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@B
M1DE,12(I.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG
M=&@H)&YA;64I("L@.2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*'-P<FEN
M=&8H"B`@("`@("`@("`@("`@("`B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ
M8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64*("`@("`@("`@("`@*2D[
M"B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N
M=&5N="DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="@D8V]N=&5N="D["B`@
M("`@("`@?0H@("`@?0H@("`@(R!]?7T*"B`@("`C($YO=R!W<FET92!O=70@
M=&AE(%!!4B!A;F0@;6%G:6,@<W1R:6YG<R![>WL*("`@("1Z:7`M/G=R:71E
M5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*"B`@("`D8V%C:&5?;F%M92`]
M('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["B`@("!I9B`H(21C86-H95]N
M86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*("`@("`@
M("!M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S
M=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@
M("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U
M+3YN97<@?3L*"B`@("`@("`@(R!7;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG
M97-T.CI32$$@-2XS."!A;F0@-2XS.0H@("`@("`@(&UY("1S:&%?=F5R<VEO
M;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@
M("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO
M;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@)&-T>"T^861D9FEL92@D;W5T
M+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@
M("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI
M('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@
M("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@(&-L;W-E
M*"1F:"D["B`@("`@("`@("`@('T*("`@("`@("!]"@H@("`@("`@("1C86-H
M95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*("`@
M('T*("`@("1C86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A
M8VAE7VYA;64I.PH@("`@)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*("`@("1F
M:"T^<')I;G0H)&-A8VAE7VYA;64I.PH@("`@)&9H+3YP<FEN="AP86-K*"=.
M)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B`@("`D9F@M/G!R
M:6YT*")<;E!!4BYP;5QN(BD["B`@("`D9F@M/F-L;W-E.PH@("`@8VAM;V0@
M,#<U-2P@)&]U=#L*("`@(",@?7U]"@H@("`@97AI=#L*?0HC('U]?0H*(R!0
M<F5P87)E("1P<F]G;F%M92!I;G1O(%!!4B!F:6QE(&-A8VAE('M[>PI["B`@
M("!L87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["@H@("`@7V9I>%]P
M<F]G;F%M92@I.PH*("`@(",@3F]W(&QO860@=&AE(%!!4B!F:6QE(&%N9"!P
M=70@:70@:6YT;R!005(Z.DQI8D-A8VAE('M[>PH@("`@<F5Q=6ER92!005([
M"B`@("!005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H*("`@('L*
M("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D
M7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@1FEL93HZ1FEN9#L*
M("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII<#L*("`@('T*("`@(&UY("1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@(&UY("1F:"`]($E/.CI&:6QE
M+3YN97<["B`@("`D9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D
M:64@(B0A.B`D0"(["B`@("`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@
M(B0A.B`D0"(["@H@("`@<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*("`@
M("1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PH*("`@("1Q=6EE
M="`]("$D14Y6>U!!4E]$14)51WT["B`@("!O=71S*'%Q*%PD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*"B`@("!I9B`H9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN
M="$*("`@("`@("!F;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S
M("D@>PH@("`@("`@("`@("!N97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y
M.PH@("`@("`@("`@("!M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE
M3F%M93L*("`@("`@("`@("`@;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^
M(&U["B`@("`@("`@("`@("`@("!>"B`@("`@("`@("`@("`@("`O/W-H;&EB
M+PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]
M+RD_"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA
M;65]+RD_"B`@("`@("`@("`@("`@("`H6UXO72LI"B`@("`@("`@("`@("`@
M("`D"B`@("`@("`@("`@('UX.PH@("`@("`@("`@("!M>2`D97AT<F%C=%]N
M86UE(#T@)#$["B`@("`@("`@("`@(&UY("1D97-T7VYA;64@/2!&:6QE.CI3
M<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*
M("`@("`@("`@("`@:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M
M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*("`@("`@("`@("`@("`@(&]U
M=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D
M>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@('T@96QS
M92!["B`@("`@("`@("`@("`@("!O=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB
M97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B`@("`@("`@("`@("`@("`D
M;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["B`@("`@
M("`@("`@("`@("!C:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@
M(FAP=7@B.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@?0H@("`@(R!]
M?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S(&YO(&UA:6XN<&P@=&\@<G5N+"!S
M:&]W('5S86=E('M[>PIU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M
M97TI('L*("`@(&1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@
M6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A
M<B!=(%L@<')O9W)A;2YP;"!="B`@("`@("`D,"!;("U"?"UB(%T@6RU/;W5T
M9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0HC('U]?0H*<W5B($-R96%T
M95!A=&@@>PH@("`@;7D@*"1N86UE*2`]($!?.PH@("`@"B`@("!R97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@*"1B87-E;F%M92P@)'!A=&@L("1E
M>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ
M)RDI.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.E!A=&@["B`@("`*("`@($9I
M;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M
M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*"G-U8B!R97%U:7)E7VUO9'5L97,@
M>PH@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/
M(&YE("=-4U=I;C,R)SL*"B`@("!R97%U:7)E(&QI8CL*("`@(')E<75I<F4@
M1'EN84QO861E<CL*("`@(')E<75I<F4@:6YT96=E<CL*("`@(')E<75I<F4@
M<W1R:6-T.PH@("`@<F5Q=6ER92!W87)N:6YG<SL*("`@(')E<75I<F4@=F%R
M<SL*("`@(')E<75I<F4@0V%R<#L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD[
M"B`@("!R97%U:7)E($5R<FYO.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["B`@("!R97%U:7)E($5X<&]R=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*
M("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E
M8SL*("`@(')E<75I<F4@6%-,;V%D97(["B`@("!R97%U:7)E($-O;F9I9SL*
M("`@(')E<75I<F4@24\Z.DAA;F1L93L*("`@(')E<75I<F4@24\Z.D9I;&4[
M"B`@("!R97%U:7)E($-O;7!R97-S.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H
M:79E.CI::7`["B`@("!R97%U:7)E(%!!4CL*("`@(')E<75I<F4@4$%2.CI(
M96%V>3L*("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["B`@("!R97%U:7)E(&%T=')I8G5T97,["B`@
M("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I
M;C,R('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@
M(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PH@("`@
M979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*("`@
M(&5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA
M<B!].PI]"@HC(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@
M:6X@;7EL9'(O;6MT;7!D:7(N8PHC(%1H:7,@8V]D92!A;'-O(&QI=F5S(&EN
M(%!!4CHZ4V5T=7!496UP(&%S('-E=%]P87)?=&5M<%]E;G8A"G-U8B!?<V5T
M7W!A<E]T96UP('L*("`@(&EF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*("`@("`@("`D<&%R7W1E
M;7`@/2`D,3L*("`@("`@("!R971U<FX["B`@("!]"@H@("`@9F]R96%C:"!M
M>2`D<&%T:"`H"B`@("`@("`@*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$
M25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"B`@("`@("`@<7<H($,Z
M7%Q414U0("]T;7`@+B`I"B`@("`I('L*("`@("`@("!N97AT('5N;&5S<R!D
M969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@
M("`@;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*("`@("`@("`C
M(&1O97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E=F%L('LH)'!W
M=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["@H@("`@("`@
M(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@("`@
M("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*
M("`@("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@("`@("`@("`@
M)'5S97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@("!E;'-E('L*
M("`@("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.
M5GM54T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@("`@)'5S97)N
M86UE(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I<B`]("(D<&%T
M:"1#;VYF:6=[7V1E;&EM?7!A<BTD=7-E<FYA;64B.PH@("`@("`@(&UK9&ER
M("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%04Y]
M(&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@("`@
M("`@("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@("`@
M("`@("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A9"`D
M9F@L(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<,$-!
M0TA%(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*("`@
M("`@("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@("`@
M("`@("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S=&UP
M9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&UY
M("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI3
M2$$M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@
M("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[
M($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O<FMA
M<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@
M("`@("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S
M=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF("@D
M<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS
M.2<I('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G
M;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@("`@
M("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H)&-T
M>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@
M("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("`@
M("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG
M97-T(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@8VQO
M<V4H)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@
M("1%3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER("X]
M("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@("`@
M("1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@)'-T
M;7!D:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R7W1E
M;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@
M/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT+"`D
M8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL
M96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.5GM0
M05)?0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M92`D
M9FEL96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@
M("`@?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N
M86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F:"P@
M)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I.PH@
M("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*(R!S86UE(&-O9&4@;&EV
M97,@:6X@4$%2.CI3971U<%!R;V=N86UE.CIS971?<')O9VYA;64*<W5B(%]S
M971?<')O9VYA;64@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!
M345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B`@("`@
M("`@)'!R;V=N86UE(#T@)#$["B`@("!]"@H@("`@)'!R;V=N86UE('Q\/2`D
M,#L*"B`@("!I9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M
M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*("`@("`@("`D<')O9VYA;64@
M/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI("L@,2D["B`@("!]"@H@("`@:68@*"$D14Y6>U!!4E]04D]'
M3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#X]
M(#`I('L*("`@("`@("!I9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE
M*2!["B`@("`@("`@("`@(')E='5R;B!I9B`M<R`D9F@["B`@("`@("`@?0H@
M("`@("`@(&EF("@M<R`B)'!R;V=N86UE)$-O;F9I9WM?97AE?2(I('L*("`@
M("`@("`@("`@)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["B`@("`@("`@
M("`@(')E='5R;CL*("`@("`@("!]"B`@("!]"@H@("`@9F]R96%C:"!M>2`D
M9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(
M?2D@>PH@("`@("`@(&YE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N
M9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PH@("`@("`@("1D:7(@/7X@<R]<
M421#;VYF:6=[7V1E;&EM?5Q%)"\O.PH@("`@("`@("@H)'!R;V=N86UE(#T@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL
M(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B`@("`@("`@*"@D<')O9VYA;64@
M/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0H@("`@
M("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92([
M"B`@("!]"GT*"G-U8B!?9FEX7W!R;V=N86UE('L*("`@("0P(#T@)'!R;V=N
M86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["B`@("!I9B`H:6YD97@H)'!R
M;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PH@("`@("`@("1P<F]G
M;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*"B`@
M("`C(%A86"`M(&AA8VL@=&\@;6%K92!05T0@=V]R:PH@("`@;7D@)'!W9"`]
M("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"B`@("`@
M("`@("`@("`@("`Z("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS
M,CHZ1V5T0W=D*"D@.B!@<'=D8"D["B`@("!C:&]M<"@D<'=D*3L*("`@("1P
M<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P
M=V0D0V]N9FEG>U]D96QI;7TO.PH*("`@("1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0H*<W5B(%]P87)?:6YI=%]E;G8@>PH@("`@:68@*"`D
M14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PH@("`@("`@(')E='5R
M;CL*("`@('T@96QS92!["B`@("`@("`@)$5.5GM005)?24Y)5$E!3$E:141]
M(#T@,CL*("`@('T*"B`@("!F;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*("`@("`@
M("!D96QE=&4@)$5.5GLG4$%27R<N)%]].PH@("`@?0H@("`@9F]R("AQ=R\@
M5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PH@("`@("`@("1%3E9[)U!!
M4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%
M3E9[)U!!4E]'3$]"04Q?)RXD7WT["B`@("!]"@H@("`@;7D@)'!A<E]C;&5A
M;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["@H@("`@
M:68@*"1%3E9[4$%27U1%35!]*2!["B`@("`@("`@9&5L971E("1%3E9[4$%2
M7T-,14%.?3L*("`@('T*("`@(&5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,
M3T)!3%]#3$5!3GTI('L*("`@("`@("!M>2`D=F%L=64@/2!S=6)S='(H)'!A
M<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PH@("`@("`@("1%3E9[
M4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K
M*2\["B`@("!]"GT*"G-U8B!O=71S('L*("`@(')E='5R;B!I9B`D<75I970[
M"B`@("!I9B`H)&QO9V9H*2!["B`@("`@("`@<')I;G0@)&QO9V9H(")`7UQN
M(CL*("`@('T*("`@(&5L<V4@>PH@("`@("`@('!R:6YT(")`7UQN(CL*("`@
M('T*?0H*<W5B(&EN:71?:6YC('L*("`@(')E<75I<F4@0V]N9FEG.PH@("`@
M<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[
M)%]]+"!Q=R@*("`@("`@("!A<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R
M8VAE>'`@<VET96QI8F5X<`H@("`@("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R
M;&EB97AP"B`@("`I.PI]"@HC(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*
M(R!4:&4@;6%I;B!P86-K86=E(&9O<B!S8W)I<'0@97AE8W5T:6]N"@IP86-K
M86=E(&UA:6X["@IR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ
M9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["@ID:64@<7$H<&%R
M+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S
M=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"B`@("!U;FQE<W,@+64@)'!R;V=N
M86UE.PH*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO
M7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["@I].PH*)#HZ
M7U]%4E)/4B`]("1`(&EF("1`.PI]"@I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ
M7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T52
M4D]2(&EF("0Z.E]?15)23U(["@HQ.PH*(VQI;F4@,3`Q,@H*7U]%3D1?7PH`
M```!&P,[V````!H```#$:/__]````-1H__\,`0``%&G__R0!``"$?___3`$`
M`'2`__]T`0``E(#__XP!``#D@/__I`$``#2!___$`0``=('__]P!``!4@___
M]`$``-2$__\D`@``=(7__SP"``"DA___9`(``-2(__^<`@``I(K__[0"``#4
MBO__S`(``.2+___D`@``9(S__P0#``"4CO__)`,``(20__]<`P``1)O__Y0#
M```DG___O`,``%2?___4`P``I)___^P#``#$G___!`0``-2?__\<!```%```
M```````!>E(``7@0`1L,!PB0`0``%````!P```#(9___`P``````````````
M%````#0```#`9___-```````````````)````$P```#H9___:Q8```!!#A!'
M#AA'#J@$`I:#`X8"`````````"0```!T````,'[__^0`````38\"C`5;#D!%
MC@.-!(8&@P<````````4````G````/A^__\5`````$0.(``````4````M```
M``!___],`````$0.$``````<````S````#A___])`````$$.$$.&`D$.&$0.
M,$6#`Q0```#L````:'___T``````1`X0`````!0````$`0``D'___]D!````
M00X00H,"`"P````<`0``6('__WT!````0@X00@X80@X@00XH0X8%C`2-`XX"
M00XP1P[``46#!A0```!,`0``J(+__YL`````00X00X,"`"0```!D`0``,(/_
M_R<"````68T$C`6&!H,'3@Y03X\"C@,````````T````C`$``#B%__\D`0``
M`$(.$$(.&$(.($.-!(X#CP)"#BA&C`5!#C!!#CA%@P>&!D0.@`$``!0```#$
M`0``,(;__\L!````1`Y``````!0```#<`0``Z(?__R(`````1`X0`````!0`
M``#T`0```(C__P(!````1`X00X,"`!P````,`@``^(C__W\`````00X00X8"
M00X81`X@@P,`'````"P"``!8B?__*P(```!!#A!$#C!=@P(````````T````
M3`(``&B+___K`0```$(.$$(.&$(.($.-!(X#CP)"#BA#C`5&#C!!#CA'#N`(
M4X,'A@8``#0```"$`@``((W__[@*````0@X00@X80@X@0@XH00XP00XX0X,'
MA@:,!8T$C@./`DP.T(0"````)````+P"``"HE___U`,```!"#A!$#AA!#B!!
M#BA$#C"#!88$C`.-`A0```#D`@``8)O__RT`````1`X0`````!0```#\`@``
M>)O__TH`````1`X0`````!0````4`P``L)O__Q@``````````````!0````L
M`P``N)O__P(``````````````"0```!$`P``L)O__XD`````48P%A@9?#D!&
M@P>/`HX#C00``````````````````/__________``````````#_________
M_P`````````````````````!``````````$``````````0````````"C`@``
M``````$`````````K@(````````!`````````+@"`````````0`````````'
M`P````````$`````````+@0````````,`````````+`?0```````#0``````
M``!H74````````0`````````:`)```````#U_O]O`````+@%0```````!0``
M``````!`$4````````8`````````P`9````````*`````````*H%````````
M"P`````````8`````````!4````````````````````#`````````$##8```
M`````@`````````@!P```````!0`````````!P`````````7`````````)`8
M0```````!P`````````P&$````````@`````````8``````````)````````
M`!@`````````_O__;P````#0%T```````/___V\``````@````````#P__]O
M`````.H60```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#`Q6```````$#!8```````````
M`````````````````-X?0```````[A]```````#^'T````````X@0```````
M'B!````````N($```````#X@0```````3B!```````!>($```````&X@0```
M````?B!```````".($```````)X@0```````KB!```````"^($```````,X@
M0```````WB!```````#N($```````/X@0```````#B%````````>(4``````
M`"XA0```````/B%```````!.(4```````%XA0```````;B%```````!^(4``
M`````(XA0```````GB%```````"N(4```````+XA0```````SB%```````#>
M(4```````.XA0```````_B%````````.(D```````!XB0```````+B)`````
M```^(D```````$XB0```````7B)```````!N(D```````'XB0```````CB)`
M``````">(D```````*XB0```````OB)```````#.(D```````-XB0```````
M[B)```````#^(D````````XC0```````'B-````````N(T```````#XC0```
M````3B-```````!>(T```````&XC0```````?B-```````".(T```````)XC
M0```````KB-```````"^(T```````,XC0```````WB-```````#N(T``````
M`/XC0```````#B1````````>)$```````"XD0```````/B1```````!.)$``
M`````%XD0```````;B1```````!^)$```````(XD0```````````````````
M`````````/____\`````P&!```````#I6P```````$=#0SH@*$1E8FEA;B`T
M+C0N-2TX*2`T+C0N-0``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N04))+71A
M9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T
M<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA
M+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`
M+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+FIC<@`N9'EN86UI8P`N9V]T`"YG
M;W0N<&QT`"YD871A`"YB<W,`+F-O;6UE;G0`````````````````````````
M````````````````````````````````````````````````````````````
M``````````L````!`````@```````````D`````````"````````'0``````
M``````````````$````````````````````3````!P````(`````````(`)`
M```````@`@```````"`````````````````````$````````````````````
M(0````<````"`````````$`"0```````0`(````````D````````````````
M````!````````````````````#@````%`````@````````!H`D```````&@"
M````````3`,````````&``````````@`````````!``````````T````]O__
M;P(`````````N`5```````"X!0````````0!````````!@`````````(````
M````````````````/@````L````"`````````,`&0```````P`8```````"`
M"@````````<````!````"``````````8`````````$8````#`````@``````
M``!`$4```````$`1````````J@4```````````````````$`````````````
M``````!.````____;P(`````````ZA9```````#J%@```````.``````````
M!@`````````"``````````(`````````6P```/[__V\"`````````-`70```
M````T!<```````!@``````````<````"````"````````````````````&H`
M```$`````@`````````P&$```````#`8````````8``````````&````````
M``@`````````&`````````!T````!`````(`````````D!A```````"0&```
M`````"`'````````!@````T````(`````````!@`````````?@````$````&
M`````````+`?0```````L!\````````8````````````````````!```````
M`````````````'D````!````!@````````#('T```````,@?````````T`0`
M``````````````````0`````````$`````````"$`````0````8`````````
MH"1```````"@)````````,@X```````````````````0````````````````
M````B@````$````&`````````&A=0```````:%T````````.````````````
M````````!````````````````````)`````!`````@````````"`74``````
M`(!=````````2E\``````````````````"````````````````````"8````
M`0````(`````````S+Q```````#,O````````-P````````````````````$
M````````````````````I@````$````"`````````*B]0```````J+T`````
M``!L`P``````````````````"````````````````````+`````!`````P``
M```````8P6```````!C!````````$`````````````````````@`````````
M``````````"W`````0````,`````````*,%@```````HP0```````!``````
M```````````````(````````````````````O@````$````#`````````#C!
M8```````.,$````````(````````````````````"```````````````````
M`,,````&`````P````````!`P6```````$#!````````\`$````````'````
M``````@`````````$`````````#,`````0````,`````````,,-@```````P
MPP```````!`````````````````````(``````````@`````````T0````$`
M```#`````````$##8```````0,,```````!X`@``````````````````"```
M```````(`````````-H````!`````P````````"XQ6```````+C%````````
M*`````````````````````@```````````````````#@````"`````,`````
M````X,5@``````#@Q0```````(`$```````````````````@````````````
M````````Y0````$````P````````````````````X,4````````<````````
M`````````````0`````````!``````````$````#````````````````````
L`````/S%````````[@````````````````````$`````````````````````
